# coding: utf-8

"""
    aind-sharepoint-service

     ## aind-sharepoint-service  Service to pull data from Sharepoint.  

    The version of the OpenAPI document: 0.1.5
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from aind_sharepoint_service_async_client.models.lightcycle import Lightcycle
from aind_sharepoint_service_async_client.models.nsb2023_aind_project_name import NSB2023AindProjectName
from aind_sharepoint_service_async_client.models.nsb2023_behavior import NSB2023Behavior
from aind_sharepoint_service_async_client.models.nsb2023_behavior_autotrain_curriculum import NSB2023BehaviorAutotrainCurriculum
from aind_sharepoint_service_async_client.models.nsb2023_behavior_curriculum_version import NSB2023BehaviorCurriculumVersion
from aind_sharepoint_service_async_client.models.nsb2023_behavior_destination import NSB2023BehaviorDestination
from aind_sharepoint_service_async_client.models.nsb2023_behavior_fiber_photometry import NSB2023BehaviorFiberPhotometry
from aind_sharepoint_service_async_client.models.nsb2023_behavior_fip_mode import NSB2023BehaviorFipMode
from aind_sharepoint_service_async_client.models.nsb2023_behavior_first_fip_stage import NSB2023BehaviorFirstFipStage
from aind_sharepoint_service_async_client.models.nsb2023_behavior_first_video_recording_stage import NSB2023BehaviorFirstVideoRecordingStage
from aind_sharepoint_service_async_client.models.nsb2023_behavior_platform import NSB2023BehaviorPlatform
from aind_sharepoint_service_async_client.models.nsb2023_behavior_type import NSB2023BehaviorType
from aind_sharepoint_service_async_client.models.nsb2023_black_cement import NSB2023BlackCement
from aind_sharepoint_service_async_client.models.nsb2023_burr1_fiber_type import NSB2023Burr1FiberType
from aind_sharepoint_service_async_client.models.nsb2023_burr1_hemisphere import NSB2023Burr1Hemisphere
from aind_sharepoint_service_async_client.models.nsb2023_burr1_injection_device import NSB2023Burr1InjectionDevice
from aind_sharepoint_service_async_client.models.nsb2023_burr1_intended_ccf_target import NSB2023Burr1IntendedCcfTarget
from aind_sharepoint_service_async_client.models.nsb2023_burr1_intended_measurement_blue import NSB2023Burr1IntendedMeasurementBlue
from aind_sharepoint_service_async_client.models.nsb2023_burr1_intended_measurement_green import NSB2023Burr1IntendedMeasurementGreen
from aind_sharepoint_service_async_client.models.nsb2023_burr1_intended_measurement_isosbestic import NSB2023Burr1IntendedMeasurementIsosbestic
from aind_sharepoint_service_async_client.models.nsb2023_burr1_intended_measurement_red import NSB2023Burr1IntendedMeasurementRed
from aind_sharepoint_service_async_client.models.nsb2023_burr1_perform_during import NSB2023Burr1PerformDuring
from aind_sharepoint_service_async_client.models.nsb2023_burr1_spinal_location import NSB2023Burr1SpinalLocation
from aind_sharepoint_service_async_client.models.nsb2023_burr1_status import NSB2023Burr1Status
from aind_sharepoint_service_async_client.models.nsb2023_burr1_virus_biosaftey_level_bsl import NSB2023Burr1VirusBiosafteyLevelBsl
from aind_sharepoint_service_async_client.models.nsb2023_burr2_fiber_type import NSB2023Burr2FiberType
from aind_sharepoint_service_async_client.models.nsb2023_burr2_hemisphere import NSB2023Burr2Hemisphere
from aind_sharepoint_service_async_client.models.nsb2023_burr2_injection_device import NSB2023Burr2InjectionDevice
from aind_sharepoint_service_async_client.models.nsb2023_burr2_intended_ccf_target import NSB2023Burr2IntendedCcfTarget
from aind_sharepoint_service_async_client.models.nsb2023_burr2_intended_measurement_blue import NSB2023Burr2IntendedMeasurementBlue
from aind_sharepoint_service_async_client.models.nsb2023_burr2_intended_measurement_green import NSB2023Burr2IntendedMeasurementGreen
from aind_sharepoint_service_async_client.models.nsb2023_burr2_intended_measurement_isosbestic import NSB2023Burr2IntendedMeasurementIsosbestic
from aind_sharepoint_service_async_client.models.nsb2023_burr2_intended_measurement_red import NSB2023Burr2IntendedMeasurementRed
from aind_sharepoint_service_async_client.models.nsb2023_burr2_perform_during import NSB2023Burr2PerformDuring
from aind_sharepoint_service_async_client.models.nsb2023_burr2_spinal_location import NSB2023Burr2SpinalLocation
from aind_sharepoint_service_async_client.models.nsb2023_burr2_status import NSB2023Burr2Status
from aind_sharepoint_service_async_client.models.nsb2023_burr2_virus_biosaftey_level_bsl import NSB2023Burr2VirusBiosafteyLevelBsl
from aind_sharepoint_service_async_client.models.nsb2023_burr3_fiber_type import NSB2023Burr3FiberType
from aind_sharepoint_service_async_client.models.nsb2023_burr3_hemisphere import NSB2023Burr3Hemisphere
from aind_sharepoint_service_async_client.models.nsb2023_burr3_injection_device import NSB2023Burr3InjectionDevice
from aind_sharepoint_service_async_client.models.nsb2023_burr3_intended_ccf_target import NSB2023Burr3IntendedCcfTarget
from aind_sharepoint_service_async_client.models.nsb2023_burr3_intended_measurement_blue import NSB2023Burr3IntendedMeasurementBlue
from aind_sharepoint_service_async_client.models.nsb2023_burr3_intended_measurement_green import NSB2023Burr3IntendedMeasurementGreen
from aind_sharepoint_service_async_client.models.nsb2023_burr3_intended_measurement_isosbestic import NSB2023Burr3IntendedMeasurementIsosbestic
from aind_sharepoint_service_async_client.models.nsb2023_burr3_intended_measurement_red import NSB2023Burr3IntendedMeasurementRed
from aind_sharepoint_service_async_client.models.nsb2023_burr3_perform_during import NSB2023Burr3PerformDuring
from aind_sharepoint_service_async_client.models.nsb2023_burr3_status import NSB2023Burr3Status
from aind_sharepoint_service_async_client.models.nsb2023_burr3_virus_biosafety_level_bsl import NSB2023Burr3VirusBiosafetyLevelBsl
from aind_sharepoint_service_async_client.models.nsb2023_burr4_fiber_type import NSB2023Burr4FiberType
from aind_sharepoint_service_async_client.models.nsb2023_burr4_hemisphere import NSB2023Burr4Hemisphere
from aind_sharepoint_service_async_client.models.nsb2023_burr4_injection_device import NSB2023Burr4InjectionDevice
from aind_sharepoint_service_async_client.models.nsb2023_burr4_intended_ccf_target import NSB2023Burr4IntendedCcfTarget
from aind_sharepoint_service_async_client.models.nsb2023_burr4_intended_measurement_blue import NSB2023Burr4IntendedMeasurementBlue
from aind_sharepoint_service_async_client.models.nsb2023_burr4_intended_measurement_green import NSB2023Burr4IntendedMeasurementGreen
from aind_sharepoint_service_async_client.models.nsb2023_burr4_intended_measurement_isosbestic import NSB2023Burr4IntendedMeasurementIsosbestic
from aind_sharepoint_service_async_client.models.nsb2023_burr4_intended_measurement_red import NSB2023Burr4IntendedMeasurementRed
from aind_sharepoint_service_async_client.models.nsb2023_burr4_perform_during import NSB2023Burr4PerformDuring
from aind_sharepoint_service_async_client.models.nsb2023_burr4_status import NSB2023Burr4Status
from aind_sharepoint_service_async_client.models.nsb2023_burr4_virus_biosaftey_level_bsl import NSB2023Burr4VirusBiosafteyLevelBsl
from aind_sharepoint_service_async_client.models.nsb2023_burr5_fiber_type import NSB2023Burr5FiberType
from aind_sharepoint_service_async_client.models.nsb2023_burr5_hemisphere import NSB2023Burr5Hemisphere
from aind_sharepoint_service_async_client.models.nsb2023_burr5_injection_device import NSB2023Burr5InjectionDevice
from aind_sharepoint_service_async_client.models.nsb2023_burr5_intended_ccf_target import NSB2023Burr5IntendedCcfTarget
from aind_sharepoint_service_async_client.models.nsb2023_burr5_intended_measurement_blue import NSB2023Burr5IntendedMeasurementBlue
from aind_sharepoint_service_async_client.models.nsb2023_burr5_intended_measurement_green import NSB2023Burr5IntendedMeasurementGreen
from aind_sharepoint_service_async_client.models.nsb2023_burr5_intended_measurement_isosbestic import NSB2023Burr5IntendedMeasurementIsosbestic
from aind_sharepoint_service_async_client.models.nsb2023_burr5_intended_measurement_red import NSB2023Burr5IntendedMeasurementRed
from aind_sharepoint_service_async_client.models.nsb2023_burr5_perform_during import NSB2023Burr5PerformDuring
from aind_sharepoint_service_async_client.models.nsb2023_burr5_status import NSB2023Burr5Status
from aind_sharepoint_service_async_client.models.nsb2023_burr5_virus_biosaftey_level_bsl import NSB2023Burr5VirusBiosafteyLevelBsl
from aind_sharepoint_service_async_client.models.nsb2023_burr6_fiber_type import NSB2023Burr6FiberType
from aind_sharepoint_service_async_client.models.nsb2023_burr6_hemisphere import NSB2023Burr6Hemisphere
from aind_sharepoint_service_async_client.models.nsb2023_burr6_injection_device import NSB2023Burr6InjectionDevice
from aind_sharepoint_service_async_client.models.nsb2023_burr6_intended_ccf_target import NSB2023Burr6IntendedCcfTarget
from aind_sharepoint_service_async_client.models.nsb2023_burr6_intended_measurement_blue import NSB2023Burr6IntendedMeasurementBlue
from aind_sharepoint_service_async_client.models.nsb2023_burr6_intended_measurement_green import NSB2023Burr6IntendedMeasurementGreen
from aind_sharepoint_service_async_client.models.nsb2023_burr6_intended_measurement_isosbestic import NSB2023Burr6IntendedMeasurementIsosbestic
from aind_sharepoint_service_async_client.models.nsb2023_burr6_intended_measurement_red import NSB2023Burr6IntendedMeasurementRed
from aind_sharepoint_service_async_client.models.nsb2023_burr6_perform_during import NSB2023Burr6PerformDuring
from aind_sharepoint_service_async_client.models.nsb2023_burr6_status import NSB2023Burr6Status
from aind_sharepoint_service_async_client.models.nsb2023_burr6_virus_biosaftey_level_bsl import NSB2023Burr6VirusBiosafteyLevelBsl
from aind_sharepoint_service_async_client.models.nsb2023_burr_hole1 import NSB2023BurrHole1
from aind_sharepoint_service_async_client.models.nsb2023_burr_hole2 import NSB2023BurrHole2
from aind_sharepoint_service_async_client.models.nsb2023_burr_hole3 import NSB2023BurrHole3
from aind_sharepoint_service_async_client.models.nsb2023_burr_hole4 import NSB2023BurrHole4
from aind_sharepoint_service_async_client.models.nsb2023_burr_hole5 import NSB2023BurrHole5
from aind_sharepoint_service_async_client.models.nsb2023_burr_hole6 import NSB2023BurrHole6
from aind_sharepoint_service_async_client.models.nsb2023_care_moduele import NSB2023CareModuele
from aind_sharepoint_service_async_client.models.nsb2023_contusion_hematoma import NSB2023ContusionHematoma
from aind_sharepoint_service_async_client.models.nsb2023_craniotomy_perform_during import NSB2023CraniotomyPerformDuring
from aind_sharepoint_service_async_client.models.nsb2023_craniotomy_type import NSB2023CraniotomyType
from aind_sharepoint_service_async_client.models.nsb2023_edema_swelling import NSB2023EdemaSwelling
from aind_sharepoint_service_async_client.models.nsb2023_fiber_implant1_length import NSB2023FiberImplant1Length
from aind_sharepoint_service_async_client.models.nsb2023_fiber_implant2_length import NSB2023FiberImplant2Length
from aind_sharepoint_service_async_client.models.nsb2023_fiber_implant3_length import NSB2023FiberImplant3Length
from aind_sharepoint_service_async_client.models.nsb2023_fiber_implant4_length import NSB2023FiberImplant4Length
from aind_sharepoint_service_async_client.models.nsb2023_fiber_implant5_length import NSB2023FiberImplant5Length
from aind_sharepoint_service_async_client.models.nsb2023_fiber_implant6_length import NSB2023FiberImplant6Length
from aind_sharepoint_service_async_client.models.nsb2023_follow_up_nanoject_number import NSB2023FollowUpNanojectNumber
from aind_sharepoint_service_async_client.models.nsb2023_follow_up_workstation import NSB2023FollowUpWorkstation
from aind_sharepoint_service_async_client.models.nsb2023_folow_up_ionto_number import NSB2023FolowUpIontoNumber
from aind_sharepoint_service_async_client.models.nsb2023_headpost import NSB2023Headpost
from aind_sharepoint_service_async_client.models.nsb2023_headpost_perform_during import NSB2023HeadpostPerformDuring
from aind_sharepoint_service_async_client.models.nsb2023_iacuc_protocol import NSB2023IacucProtocol
from aind_sharepoint_service_async_client.models.nsb2023_implant_id_coverslip_type import NSB2023ImplantIdCoverslipType
from aind_sharepoint_service_async_client.models.nsb2023_initial_ionto_number import NSB2023InitialIontoNumber
from aind_sharepoint_service_async_client.models.nsb2023_initial_nanoject_number import NSB2023InitialNanojectNumber
from aind_sharepoint_service_async_client.models.nsb2023_initial_work_station import NSB2023InitialWorkStation
from aind_sharepoint_service_async_client.models.nsb2023_inj1_retsetting import NSB2023Inj1Retsetting
from aind_sharepoint_service_async_client.models.nsb2023_inj1_type import NSB2023Inj1Type
from aind_sharepoint_service_async_client.models.nsb2023_inj2_retsetting import NSB2023Inj2Retsetting
from aind_sharepoint_service_async_client.models.nsb2023_inj2_type import NSB2023Inj2Type
from aind_sharepoint_service_async_client.models.nsb2023_inj3_retsetting import NSB2023Inj3Retsetting
from aind_sharepoint_service_async_client.models.nsb2023_inj3_type import NSB2023Inj3Type
from aind_sharepoint_service_async_client.models.nsb2023_inj4_retsetting import NSB2023Inj4Retsetting
from aind_sharepoint_service_async_client.models.nsb2023_inj4_type import NSB2023Inj4Type
from aind_sharepoint_service_async_client.models.nsb2023_inj5_retsetting import NSB2023Inj5Retsetting
from aind_sharepoint_service_async_client.models.nsb2023_inj5_type import NSB2023Inj5Type
from aind_sharepoint_service_async_client.models.nsb2023_inj6_retsetting import NSB2023Inj6Retsetting
from aind_sharepoint_service_async_client.models.nsb2023_inj6_type import NSB2023Inj6Type
from aind_sharepoint_service_async_client.models.nsb2023_laceration import NSB2023Laceration
from aind_sharepoint_service_async_client.models.nsb2023_lims_project import NSB2023LimsProject
from aind_sharepoint_service_async_client.models.nsb2023_lims_required import NSB2023LimsRequired
from aind_sharepoint_service_async_client.models.nsb2023_lims_taskflow import NSB2023LimsTaskflow
from aind_sharepoint_service_async_client.models.nsb2023_of_burr_holes import NSB2023OfBurrHoles
from aind_sharepoint_service_async_client.models.nsb2023_physiology_type import NSB2023PhysiologyType
from aind_sharepoint_service_async_client.models.nsb2023_procedure import NSB2023Procedure
from aind_sharepoint_service_async_client.models.nsb2023_procedure_category import NSB2023ProcedureCategory
from aind_sharepoint_service_async_client.models.nsb2023_procedure_slots import NSB2023ProcedureSlots
from aind_sharepoint_service_async_client.models.nsb2023_project_id import NSB2023ProjectId
from aind_sharepoint_service_async_client.models.nsb2023_protocol import NSB2023Protocol
from aind_sharepoint_service_async_client.models.nsb2023_sex import NSB2023Sex
from aind_sharepoint_service_async_client.models.nsb2023_sinus_bleed import NSB2023SinusBleed
from aind_sharepoint_service_async_client.models.nsb2023_surgery_status import NSB2023SurgeryStatus
from aind_sharepoint_service_async_client.models.nsb2023_thermistor import NSB2023Thermistor
from aind_sharepoint_service_async_client.models.nsb2023_well import NSB2023Well
from typing import Optional, Set
from typing_extensions import Self

class NSB2023List(BaseModel):
    """
    Fields in SharePoint list.
    """ # noqa: E501
    age_x0020_at_x0020_injection: Optional[StrictStr] = Field(default=None, alias="Age_x0020_at_x0020_Injection")
    aind_x0020_project_x0020_name: Optional[NSB2023AindProjectName] = Field(default=None, alias="AIND_x0020_Project_x0020_Name")
    ap2nd_inj: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="AP2ndInj")
    app_author: Optional[StrictInt] = Field(default=None, alias="AppAuthor")
    app_editor: Optional[StrictStr] = Field(default=None, alias="AppEditor")
    attachments: Optional[StrictBool] = Field(default=None, alias="Attachments")
    author: Optional[StrictStr] = Field(default=None, alias="Author")
    author_id: Optional[StrictInt] = Field(default=None, alias="AuthorId")
    author_lookup_id: Optional[StrictInt] = Field(default=None, alias="AuthorLookupId")
    editor_id: Optional[StrictInt] = Field(default=None, alias="EditorId")
    editor_lookup_id: Optional[StrictInt] = Field(default=None, alias="EditorLookupId")
    test1_lookup_id: Optional[StrictInt] = Field(default=None, alias="Test1LookupId")
    test_x0020_1st_x0020_round_x0020_lookup_id: Optional[StrictInt] = Field(default=None, alias="TEST_x0020_1st_x0020_Round_x0020LookupId")
    behavior: Optional[NSB2023Behavior] = Field(default=None, alias="Behavior")
    behavior_x0020_autotrain_x0020_c: Optional[NSB2023BehaviorAutotrainCurriculum] = Field(default=None, alias="Behavior_x0020_Autotrain_x0020_C")
    behavior_x0020_complete: Optional[StrictStr] = Field(default=None, alias="Behavior_x0020_Complete")
    behavior_x0020_curriculum_x0020_: Optional[NSB2023BehaviorCurriculumVersion] = Field(default=None, alias="Behavior_x0020_Curriculum_x0020_")
    behavior_x0020_destination: Optional[NSB2023BehaviorDestination] = Field(default=None, alias="behavior_x0020_Destination")
    behavior_x0020_fiber_x0020_photo: Optional[NSB2023BehaviorFiberPhotometry] = Field(default=None, alias="Behavior_x0020_Fiber_x0020_Photo")
    behavior_x0020_first_x0020_video: Optional[NSB2023BehaviorFirstVideoRecordingStage] = Field(default=None, alias="Behavior_x0020_First_x0020_Video")
    behavior_x0020_first_x0020_fip_x: Optional[NSB2023BehaviorFirstFipStage] = Field(default=None, alias="Behavior_x0020_First_x0020_FIP_x")
    behavior_x0020_platform: Optional[NSB2023BehaviorPlatform] = Field(default=None, alias="Behavior_x0020_Platform")
    behavior_x0020_type: Optional[NSB2023BehaviorType] = Field(default=None, alias="Behavior_x0020_Type")
    behavior_x0020_fip_x0020_mode: Optional[NSB2023BehaviorFipMode] = Field(default=None, alias="Behavior_x0020_FIP_x0020_Mode")
    black_x0020_cement: Optional[NSB2023BlackCement] = Field(default=None, alias="Black_x0020_Cement")
    breg2_lamb: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Breg2Lamb")
    burr1_x0020_injection_x0020_devi: Optional[NSB2023Burr1InjectionDevice] = Field(default=None, alias="Burr1_x0020_Injection_x0020_Devi")
    burr1_x0020_perform_x0020_during: Optional[NSB2023Burr1PerformDuring] = Field(default=None, alias="Burr1_x0020_Perform_x0020_During")
    burr1_x0020_virus_x0020_biosafte: Optional[NSB2023Burr1VirusBiosafteyLevelBsl] = Field(default=None, description="BSL & Material injected.If other PI must provide material in requestor comments.", alias="Burr1_x0020_Virus_x0020_Biosafte")
    burr2_x0020_injection_x0020_devi: Optional[NSB2023Burr2InjectionDevice] = Field(default=None, alias="Burr2_x0020_Injection_x0020_Devi")
    burr2_x0020_perform_x0020_during: Optional[NSB2023Burr2PerformDuring] = Field(default=None, alias="Burr2_x0020_Perform_x0020_During")
    burr2_x0020_status: Optional[NSB2023Burr2Status] = Field(default=None, alias="Burr2_x0020_Status")
    burr2_x0020_virus_x0020_biosafte: Optional[NSB2023Burr2VirusBiosafteyLevelBsl] = Field(default=None, description="BSL & Material injected.If other PI must provide material in requestor comments.", alias="Burr2_x0020_Virus_x0020_Biosafte")
    burr3_x0020_injection_x0020_devi: Optional[NSB2023Burr3InjectionDevice] = Field(default=None, alias="Burr3_x0020_Injection_x0020_Devi")
    burr3_x0020_perform_x0020_during: Optional[NSB2023Burr3PerformDuring] = Field(default=None, alias="Burr3_x0020_Perform_x0020_During")
    burr3_x0020_status: Optional[NSB2023Burr3Status] = Field(default=None, alias="Burr3_x0020_Status")
    burr3_x0020_virus_x0020_biosafet: Optional[NSB2023Burr3VirusBiosafetyLevelBsl] = Field(default=None, description="BSL & Material injected.If other PI must provide material in requestor comments.", alias="Burr3_x0020_Virus_x0020_Biosafet")
    burr3_x0020_a_x002f_p: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr3_x0020_A_x002f_P")
    burr3_x0020_d_x002f_v: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr3_x0020_D_x002f_V")
    burr3_x0020_m_x002f_l: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr3_x0020_M_x002f_L")
    burr4_x0020_injection_x0020_devi: Optional[NSB2023Burr4InjectionDevice] = Field(default=None, alias="Burr4_x0020_Injection_x0020_Devi")
    burr4_x0020_perform_x0020_during: Optional[NSB2023Burr4PerformDuring] = Field(default=None, alias="Burr4_x0020_Perform_x0020_During")
    burr4_x0020_status: Optional[NSB2023Burr4Status] = Field(default=None, alias="Burr4_x0020_Status")
    burr4_x0020_virus_x0020_biosafte: Optional[NSB2023Burr4VirusBiosafteyLevelBsl] = Field(default=None, description="BSL & Material injected.If other PI must provide material in requestor comments.", alias="Burr4_x0020_Virus_x0020_Biosafte")
    burr4_x0020_a_x002f_p: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr4_x0020_A_x002f_P")
    burr4_x0020_d_x002f_v: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr4_x0020_D_x002f_V")
    burr4_x0020_m_x002f_l: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr4_x0020_M_x002f_L")
    burr5_x0020_injection_x0020_devi: Optional[NSB2023Burr5InjectionDevice] = Field(default=None, alias="Burr5_x0020_Injection_x0020_Devi")
    burr5_x0020_perform_x0020_during: Optional[NSB2023Burr5PerformDuring] = Field(default=None, alias="Burr5_x0020_Perform_x0020_During")
    burr5_x0020_status: Optional[NSB2023Burr5Status] = Field(default=None, alias="Burr5_x0020_Status")
    burr5_x0020_virus_x0020_biosafte: Optional[NSB2023Burr5VirusBiosafteyLevelBsl] = Field(default=None, alias="Burr5_x0020_Virus_x0020_Biosafte")
    burr6_x0020_injection_x0020_devi: Optional[NSB2023Burr6InjectionDevice] = Field(default=None, alias="Burr6_x0020_Injection_x0020_Devi")
    burr6_x0020_perform_x0020_during: Optional[NSB2023Burr6PerformDuring] = Field(default=None, alias="Burr6_x0020_Perform_x0020_During")
    burr6_x0020_status: Optional[NSB2023Burr6Status] = Field(default=None, alias="Burr6_x0020_Status")
    burr6_x0020_virus_x0020_biosafte: Optional[NSB2023Burr6VirusBiosafteyLevelBsl] = Field(default=None, alias="Burr6_x0020_Virus_x0020_Biosafte")
    burr_x0020_1_x0020_fiber_x0020_t: Optional[NSB2023Burr1FiberType] = Field(default=None, alias="Burr_x0020_1_x0020_Fiber_x0020_t")
    burr_x0020_1_x0020_grid_x0020_sp: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr_x0020_1_x0020_Grid_x0020_Sp")
    burr_x0020_1_x0020_injectable_x00: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_1_x0020_Injectable_x00")
    burr_x0020_1_x0020_injectable_x01: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_1_x0020_Injectable_x01")
    burr_x0020_1_x0020_injectable_x02: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_1_x0020_Injectable_x02")
    burr_x0020_1_x0020_injectable_x03: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_1_x0020_Injectable_x03")
    burr_x0020_1_x0020_injectable_x04: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_1_x0020_Injectable_x04")
    burr_x0020_1_x0020_injectable_x05: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_1_x0020_Injectable_x05")
    burr_x0020_1_x0020_injectable_x06: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_1_x0020_Injectable_x06")
    burr_x0020_1_x0020_injectable_x0: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_1_x0020_Injectable_x0")
    burr_x0020_1_x0020_intended_x002: Optional[List[NSB2023Burr1IntendedCcfTarget]] = Field(default=None, alias="Burr_x0020_1_x0020_Intended_x002")
    burr_x0020_1_x0020_spinal_x0020_: Optional[NSB2023Burr1SpinalLocation] = Field(default=None, alias="Burr_x0020_1_x0020_Spinal_x0020_")
    burr_x0020_1_x0020_d_x002f_v_x00: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr_x0020_1_x0020_D_x002f_V_x00")
    burr_x0020_1_x0020_dv_x0020_2: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr_x0020_1_x0020_DV_x0020_2")
    burr_x0020_1_x0020_intended_x0020: Optional[NSB2023Burr1IntendedMeasurementRed] = Field(default=None, alias="Burr_x0020_1_x0020_intended_x0020")
    burr_x0020_1_x0020_intended_x0021: Optional[NSB2023Burr1IntendedMeasurementGreen] = Field(default=None, alias="Burr_x0020_1_x0020_intended_x0021")
    burr_x0020_1_x0020_intended_x0022: Optional[NSB2023Burr1IntendedMeasurementBlue] = Field(default=None, alias="Burr_x0020_1_x0020_intended_x0022")
    burr_x0020_1_x0020_intended_x0023: Optional[NSB2023Burr1IntendedMeasurementIsosbestic] = Field(default=None, alias="Burr_x0020_1_x0020_intended_x0023")
    burr_x0020_2_x0020_fiber_x0020_t: Optional[NSB2023Burr2FiberType] = Field(default=None, alias="Burr_x0020_2_x0020_Fiber_x0020_T")
    burr_x0020_2_x0020_injectable_x00: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_2_x0020_Injectable_x00")
    burr_x0020_2_x0020_injectable_x01: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_2_x0020_Injectable_x01")
    burr_x0020_2_x0020_injectable_x02: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_2_x0020_Injectable_x02")
    burr_x0020_2_x0020_injectable_x03: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_2_x0020_Injectable_x03")
    burr_x0020_2_x0020_injectable_x04: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_2_x0020_Injectable_x04")
    burr_x0020_2_x0020_injectable_x05: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_2_x0020_Injectable_x05")
    burr_x0020_2_x0020_injectable_x06: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_2_x0020_Injectable_x06")
    burr_x0020_2_x0020_injectable_x0: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_2_x0020_Injectable_x0")
    burr_x0020_2_x0020_intended_x002: Optional[List[NSB2023Burr2IntendedCcfTarget]] = Field(default=None, alias="Burr_x0020_2_x0020_Intended_x002")
    burr_x0020_2_x0020_spinal_x0020_: Optional[NSB2023Burr2SpinalLocation] = Field(default=None, alias="Burr_x0020_2_x0020_Spinal_x0020_")
    burr_x0020_2_x0020_d_x002f_v_x000: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr_x0020_2_x0020_D_x002f_V_x000")
    burr_x0020_2_x0020_d_x002f_v_x00: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr_x0020_2_x0020_D_x002f_V_x00")
    burr_x0020_2_x0020_intended_x0020: Optional[NSB2023Burr2IntendedMeasurementRed] = Field(default=None, alias="Burr_x0020_2_x0020_intended_x0020")
    burr_x0020_2_x0020_intended_x0021: Optional[NSB2023Burr2IntendedMeasurementGreen] = Field(default=None, alias="Burr_x0020_2_x0020_intended_x0021")
    burr_x0020_2_x0020_intended_x0022: Optional[NSB2023Burr2IntendedMeasurementBlue] = Field(default=None, alias="Burr_x0020_2_x0020_intended_x0022")
    burr_x0020_2_x0020_intended_x0023: Optional[NSB2023Burr2IntendedMeasurementIsosbestic] = Field(default=None, alias="Burr_x0020_2_x0020_intended_x0023")
    burr_x0020_3_x0020_angle: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr_x0020_3_x0020_Angle")
    burr_x0020_3_x0020_fiber_x0020_t: Optional[NSB2023Burr3FiberType] = Field(default=None, alias="Burr_x0020_3_x0020_Fiber_x0020_T")
    burr_x0020_3_x0020_hemisphere: Optional[NSB2023Burr3Hemisphere] = Field(default=None, alias="Burr_x0020_3_x0020_Hemisphere")
    burr_x0020_3_x0020_injectable_x00: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_3_x0020_Injectable_x00")
    burr_x0020_3_x0020_injectable_x01: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_3_x0020_Injectable_x01")
    burr_x0020_3_x0020_injectable_x02: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_3_x0020_Injectable_x02")
    burr_x0020_3_x0020_injectable_x03: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_3_x0020_Injectable_x03")
    burr_x0020_3_x0020_injectable_x04: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_3_x0020_Injectable_x04")
    burr_x0020_3_x0020_injectable_x05: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_3_x0020_Injectable_x05")
    burr_x0020_3_x0020_injectable_x06: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_3_x0020_Injectable_x06")
    burr_x0020_3_x0020_injectable_x0: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_3_x0020_Injectable_x0")
    burr_x0020_3_x0020_intended_x002: Optional[List[NSB2023Burr3IntendedCcfTarget]] = Field(default=None, alias="Burr_x0020_3_x0020_Intended_x002")
    burr_x0020_3_x0020_d_x002f_v_x000: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr_x0020_3_x0020_D_x002f_V_x000")
    burr_x0020_3_x0020_d_x002f_v_x00: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr_x0020_3_x0020_D_x002f_V_x00")
    burr_x0020_3_x0020_intended_x0020: Optional[NSB2023Burr3IntendedMeasurementRed] = Field(default=None, alias="Burr_x0020_3_x0020_intended_x0020")
    burr_x0020_3_x0020_intended_x0021: Optional[NSB2023Burr3IntendedMeasurementGreen] = Field(default=None, alias="Burr_x0020_3_x0020_intended_x0021")
    burr_x0020_3_x0020_intended_x0022: Optional[NSB2023Burr3IntendedMeasurementBlue] = Field(default=None, alias="Burr_x0020_3_x0020_intended_x0022")
    burr_x0020_3_x0020_intended_x0023: Optional[NSB2023Burr3IntendedMeasurementIsosbestic] = Field(default=None, alias="Burr_x0020_3_x0020_intended_x0023")
    burr_x0020_4_x0020_angle: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr_x0020_4_x0020_Angle")
    burr_x0020_4_x0020_fiber_x0020_t: Optional[NSB2023Burr4FiberType] = Field(default=None, alias="Burr_x0020_4_x0020_Fiber_x0020_T")
    burr_x0020_4_x0020_hemisphere: Optional[NSB2023Burr4Hemisphere] = Field(default=None, alias="Burr_x0020_4_x0020_Hemisphere")
    burr_x0020_4_x0020_injectable_x00: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_4_x0020_Injectable_x00")
    burr_x0020_4_x0020_injectable_x01: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_4_x0020_Injectable_x01")
    burr_x0020_4_x0020_injectable_x02: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_4_x0020_Injectable_x02")
    burr_x0020_4_x0020_injectable_x03: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_4_x0020_Injectable_x03")
    burr_x0020_4_x0020_injectable_x04: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_4_x0020_Injectable_x04")
    burr_x0020_4_x0020_injectable_x05: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_4_x0020_Injectable_x05")
    burr_x0020_4_x0020_injectable_x06: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_4_x0020_Injectable_x06")
    burr_x0020_4_x0020_injectable_x0: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_4_x0020_Injectable_x0")
    burr_x0020_4_x0020_intended_x002: Optional[List[NSB2023Burr4IntendedCcfTarget]] = Field(default=None, alias="Burr_x0020_4_x0020_Intended_x002")
    burr_x0020_4_x0020_d_x002f_v_x000: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr_x0020_4_x0020_D_x002f_V_x000")
    burr_x0020_4_x0020_d_x002f_v_x00: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr_x0020_4_x0020_D_x002f_V_x00")
    burr_x0020_4_x0020_intended_x0020: Optional[NSB2023Burr4IntendedMeasurementRed] = Field(default=None, alias="Burr_x0020_4_x0020_intended_x0020")
    burr_x0020_4_x0020_intended_x0021: Optional[NSB2023Burr4IntendedMeasurementGreen] = Field(default=None, alias="Burr_x0020_4_x0020_intended_x0021")
    burr_x0020_4_x0020_intended_x0022: Optional[NSB2023Burr4IntendedMeasurementBlue] = Field(default=None, alias="Burr_x0020_4_x0020_intended_x0022")
    burr_x0020_4_x0020_intended_x0023: Optional[NSB2023Burr4IntendedMeasurementIsosbestic] = Field(default=None, alias="Burr_x0020_4_x0020_intended_x0023")
    burr_x0020_5_x0020_angle: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr_x0020_5_x0020_Angle")
    burr_x0020_5_x0020_fiber_x0020_t: Optional[NSB2023Burr5FiberType] = Field(default=None, alias="Burr_x0020_5_x0020_Fiber_x0020_t")
    burr_x0020_5_x0020_hemisphere: Optional[NSB2023Burr5Hemisphere] = Field(default=None, alias="Burr_x0020_5_x0020_Hemisphere")
    burr_x0020_5_x0020_injectable_x00: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_5_x0020_Injectable_x00")
    burr_x0020_5_x0020_injectable_x01: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_5_x0020_Injectable_x01")
    burr_x0020_5_x0020_injectable_x02: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_5_x0020_Injectable_x02")
    burr_x0020_5_x0020_injectable_x03: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_5_x0020_Injectable_x03")
    burr_x0020_5_x0020_injectable_x04: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_5_x0020_Injectable_x04")
    burr_x0020_5_x0020_injectable_x05: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_5_x0020_Injectable_x05")
    burr_x0020_5_x0020_injectable_x06: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_5_x0020_Injectable_x06")
    burr_x0020_5_x0020_injectable_x0: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_5_x0020_Injectable_x0")
    burr_x0020_5_x0020_intended_x002: Optional[List[NSB2023Burr5IntendedCcfTarget]] = Field(default=None, alias="Burr_x0020_5_x0020_Intended_x002")
    burr_x0020_5_x0020_a_x002f_p: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr_x0020_5_x0020_A_x002f_P")
    burr_x0020_5_x0020_d_x002f_v_x000: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr_x0020_5_x0020_D_x002f_V_x000")
    burr_x0020_5_x0020_d_x002f_v_x001: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr_x0020_5_x0020_D_x002f_V_x001")
    burr_x0020_5_x0020_d_x002f_v_x00: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr_x0020_5_x0020_D_x002f_V_x00")
    burr_x0020_5_x0020_intended_x0020: Optional[NSB2023Burr5IntendedMeasurementRed] = Field(default=None, alias="Burr_x0020_5_x0020_intended_x0020")
    burr_x0020_5_x0020_intended_x0021: Optional[NSB2023Burr5IntendedMeasurementGreen] = Field(default=None, alias="Burr_x0020_5_x0020_intended_x0021")
    burr_x0020_5_x0020_intended_x0022: Optional[NSB2023Burr5IntendedMeasurementBlue] = Field(default=None, alias="Burr_x0020_5_x0020_intended_x0022")
    burr_x0020_5_x0020_intended_x0023: Optional[NSB2023Burr5IntendedMeasurementIsosbestic] = Field(default=None, alias="Burr_x0020_5_x0020_intended_x0023")
    burr_x0020_5_x0020_m_x002f_l: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr_x0020_5_x0020_M_x002f_L")
    burr_x0020_6_x0020_angle: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr_x0020_6_x0020_Angle")
    burr_x0020_6_x0020_fiber_x0020_t: Optional[NSB2023Burr6FiberType] = Field(default=None, alias="Burr_x0020_6_x0020_Fiber_x0020_t")
    burr_x0020_6_x0020_hemisphere: Optional[NSB2023Burr6Hemisphere] = Field(default=None, alias="Burr_x0020_6_x0020_Hemisphere")
    burr_x0020_6_x0020_injectable_x00: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_6_x0020_Injectable_x00")
    burr_x0020_6_x0020_injectable_x01: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_6_x0020_Injectable_x01")
    burr_x0020_6_x0020_injectable_x02: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_6_x0020_Injectable_x02")
    burr_x0020_6_x0020_injectable_x03: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_6_x0020_Injectable_x03")
    burr_x0020_6_x0020_injectable_x04: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_6_x0020_Injectable_x04")
    burr_x0020_6_x0020_injectable_x05: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_6_x0020_Injectable_x05")
    burr_x0020_6_x0020_injectable_x06: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_6_x0020_Injectable_x06")
    burr_x0020_6_x0020_injectable_x0: Optional[StrictStr] = Field(default=None, alias="Burr_x0020_6_x0020_Injectable_x0")
    burr_x0020_6_x0020_intended_x002: Optional[List[NSB2023Burr6IntendedCcfTarget]] = Field(default=None, alias="Burr_x0020_6_x0020_Intended_x002")
    burr_x0020_6_x0020_a_x002f_p: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr_x0020_6_x0020_A_x002f_P")
    burr_x0020_6_x0020_d_x002f_v_x000: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr_x0020_6_x0020_D_x002f_V_x000")
    burr_x0020_6_x0020_d_x002f_v_x001: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr_x0020_6_x0020_D_x002f_V_x001")
    burr_x0020_6_x0020_d_x002f_v_x00: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr_x0020_6_x0020_D_x002f_V_x00")
    burr_x0020_6_x0020_intended_x0020: Optional[NSB2023Burr6IntendedMeasurementRed] = Field(default=None, alias="Burr_x0020_6_x0020_intended_x0020")
    burr_x0020_6_x0020_intended_x0021: Optional[NSB2023Burr6IntendedMeasurementGreen] = Field(default=None, alias="Burr_x0020_6_x0020_intended_x0021")
    burr_x0020_6_x0020_intended_x0022: Optional[NSB2023Burr6IntendedMeasurementBlue] = Field(default=None, alias="Burr_x0020_6_x0020_intended_x0022")
    burr_x0020_6_x0020_intended_x0023: Optional[NSB2023Burr6IntendedMeasurementIsosbestic] = Field(default=None, alias="Burr_x0020_6_x0020_intended_x0023")
    burr_x0020_6_x0020_m_x002f_l: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Burr_x0020_6_x0020_M_x002f_L")
    burr_x0020_hole_x0020_1_x0020_st: Optional[NSB2023Burr1Status] = Field(default=None, alias="Burr_x0020_Hole_x0020_1_x0020_st")
    burr_x0020_hole_x0020_1: Optional[NSB2023BurrHole1] = Field(default=None, alias="Burr_x0020_hole_x0020_1")
    burr_x0020_hole_x0020_2: Optional[NSB2023BurrHole2] = Field(default=None, alias="Burr_x0020_hole_x0020_2")
    burr_x0020_hole_x0020_3: Optional[NSB2023BurrHole3] = Field(default=None, alias="Burr_x0020_hole_x0020_3")
    burr_x0020_hole_x0020_4: Optional[NSB2023BurrHole4] = Field(default=None, alias="Burr_x0020_hole_x0020_4")
    burr_x0020_hole_x0020_5: Optional[NSB2023BurrHole5] = Field(default=None, alias="Burr_x0020_hole_x0020_5")
    burr_x0020_hole_x0020_6: Optional[NSB2023BurrHole6] = Field(default=None, alias="Burr_x0020_hole_x0020_6")
    care_x0020_moduele: Optional[NSB2023CareModuele] = Field(default=None, alias="Care_x0020_Moduele")
    color_tag: Optional[StrictStr] = Field(default=None, alias="_ColorTag")
    com_coplanar: Optional[NSB2023Laceration] = Field(default=None, alias="ComCoplanar")
    com_sinusbleed: Optional[NSB2023SinusBleed] = Field(default=None, alias="ComSinusbleed")
    com_swelling: Optional[NSB2023EdemaSwelling] = Field(default=None, alias="ComSwelling")
    compliance_asset_id: Optional[StrictStr] = Field(default=None, alias="ComplianceAssetId")
    content_type: Optional[StrictStr] = Field(default=None, alias="ContentType")
    contusion: Optional[NSB2023ContusionHematoma] = Field(default=None, alias="Contusion")
    craniotomy_x0020_perform_x0020_d: Optional[NSB2023CraniotomyPerformDuring] = Field(default=None, alias="Craniotomy_x0020_Perform_x0020_D")
    craniotomy_type: Optional[NSB2023CraniotomyType] = Field(default=None, alias="CraniotomyType")
    created: Optional[datetime] = Field(default=None, alias="Created")
    date1st_injection: Optional[datetime] = Field(default=None, alias="Date1stInjection")
    date_x0020_of_x0020_birth: Optional[datetime] = Field(default=None, alias="Date_x0020_of_x0020_Birth")
    date_x0020_of_x0020_surgery: Optional[datetime] = Field(default=None, alias="Date_x0020_of_x0020_Surgery")
    date_range_start: Optional[datetime] = Field(default=None, alias="DateRangeStart")
    doc_icon: Optional[StrictStr] = Field(default=None, alias="DocIcon")
    dv2nd_inj: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="DV2ndInj")
    edit: Optional[StrictStr] = Field(default=None, alias="Edit")
    editor: Optional[StrictStr] = Field(default=None, alias="Editor")
    fiber_x0020_implant1_x0020_lengt: Optional[NSB2023FiberImplant1Length] = Field(default=None, alias="Fiber_x0020_Implant1_x0020_Lengt")
    fiber_x0020_implant2_x0020_lengt: Optional[NSB2023FiberImplant2Length] = Field(default=None, alias="Fiber_x0020_Implant2_x0020_Lengt")
    fiber_x0020_implant3_x0020_lengt: Optional[NSB2023FiberImplant3Length] = Field(default=None, alias="Fiber_x0020_Implant3_x0020_Lengt")
    fiber_x0020_implant3_x0020_d_x00: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Fiber_x0020_Implant3_x0020_D_x00")
    fiber_x0020_implant4_x0020_lengt: Optional[NSB2023FiberImplant4Length] = Field(default=None, alias="Fiber_x0020_Implant4_x0020_Lengt")
    fiber_x0020_implant4_x0020_d_x00: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Fiber_x0020_Implant4_x0020_D_x00")
    fiber_x0020_implant5_x0020_lengt: Optional[NSB2023FiberImplant5Length] = Field(default=None, alias="Fiber_x0020_Implant5_x0020_Lengt")
    fiber_x0020_implant5_x0020_d_x00: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Fiber_x0020_Implant5_x0020_D_x00")
    fiber_x0020_implant6_x0020_lengt: Optional[NSB2023FiberImplant6Length] = Field(default=None, alias="Fiber_x0020_Implant6_x0020_Lengt")
    fiber_x0020_implant6_x0020_d_x00: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Fiber_x0020_Implant6_x0020_D_x00")
    fiber_implant1_dv: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="FiberImplant1DV")
    fiber_implant2_dv: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="FiberImplant2DV")
    first_inj_recovery: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="FirstInjRecovery")
    first_injection_iso_duration: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="FirstInjectionIsoDuration")
    first_injection_weight_after: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="FirstInjectionWeightAfter")
    first_injection_weight_befor: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="FirstInjectionWeightBefor")
    folder_child_count: Optional[StrictStr] = Field(default=None, alias="FolderChildCount")
    headpost: Optional[NSB2023Headpost] = Field(default=None, alias="Headpost")
    headpost_x0020_perform_x0020_dur: Optional[NSB2023HeadpostPerformDuring] = Field(default=None, alias="Headpost_x0020_Perform_x0020_Dur")
    headpost_type: Optional[NSB2023Well] = Field(default=None, alias="HeadpostType")
    hemisphere2nd_inj: Optional[NSB2023Burr2Hemisphere] = Field(default=None, alias="Hemisphere2ndInj")
    hp_iso_level: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="HPIsoLevel")
    hp_recovery: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="HPRecovery")
    hp_surgeon_comments: Optional[StrictStr] = Field(default=None, alias="HPSurgeonComments")
    hp_work_station: Optional[NSB2023InitialWorkStation] = Field(default=None, alias="HpWorkStation")
    iacuc_x0020_protocol_x0020__x002: Optional[NSB2023IacucProtocol] = Field(default=None, description="Create a secondary List for Protocols and link to drugs", alias="IACUC_x0020_Protocol_x0020__x002")
    id: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="ID")
    implant_id_coverslip_type: Optional[NSB2023ImplantIdCoverslipType] = Field(default=None, alias="ImplantIDCoverslipType")
    inj1_alternating_time: Optional[StrictStr] = Field(default=None, alias="Inj1AlternatingTime")
    inj1_angle_v2: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Inj1Angle_v2")
    inj1_current: Optional[StrictStr] = Field(default=None, alias="Inj1Current")
    inj1_ionto_time: Optional[StrictStr] = Field(default=None, alias="Inj1IontoTime")
    inj1_storage_location: Optional[StrictStr] = Field(default=None, alias="Inj1StorageLocation")
    inj1_type: Optional[NSB2023Inj1Type] = Field(default=None, alias="Inj1Type")
    inj1_virus_strain_rt: Optional[StrictStr] = Field(default=None, alias="Inj1VirusStrain_rt")
    inj1volperdepth: Optional[Union[StrictFloat, StrictInt]] = None
    inj2_alternating_time: Optional[StrictStr] = Field(default=None, alias="Inj2AlternatingTime")
    inj2_angle_v2: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Inj2Angle_v2")
    inj2_current: Optional[StrictStr] = Field(default=None, alias="Inj2Current")
    inj2_ionto_time: Optional[StrictStr] = Field(default=None, alias="Inj2IontoTime")
    inj2_storage_location: Optional[StrictStr] = Field(default=None, alias="Inj2StorageLocation")
    inj2_type: Optional[NSB2023Inj2Type] = Field(default=None, alias="Inj2Type")
    inj2_virus_strain_rt: Optional[StrictStr] = Field(default=None, alias="Inj2VirusStrain_rt")
    inj2volperdepth: Optional[Union[StrictFloat, StrictInt]] = None
    inj3_alternating_time: Optional[StrictStr] = Field(default=None, alias="Inj3AlternatingTime")
    inj3_current: Optional[StrictStr] = Field(default=None, alias="Inj3Current")
    inj3_ionto_time: Optional[StrictStr] = Field(default=None, alias="Inj3IontoTime")
    inj3_storage_location: Optional[StrictStr] = Field(default=None, alias="Inj3StorageLocation")
    inj3_type: Optional[NSB2023Inj3Type] = Field(default=None, alias="Inj3Type")
    inj3ret_setting: Optional[NSB2023Inj3Retsetting] = Field(default=None, alias="Inj3retSetting")
    inj3volperdepth: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Inj3volperdepth")
    inj4_alternating_time: Optional[StrictStr] = Field(default=None, alias="Inj4AlternatingTime")
    inj4_current: Optional[StrictStr] = Field(default=None, alias="Inj4Current")
    inj4_ionto_time: Optional[StrictStr] = Field(default=None, alias="Inj4IontoTime")
    inj4_storage_location: Optional[StrictStr] = Field(default=None, alias="Inj4StorageLocation")
    inj4_type: Optional[NSB2023Inj4Type] = Field(default=None, alias="Inj4Type")
    inj4_virus_strain_rt: Optional[StrictStr] = Field(default=None, alias="Inj4VirusStrain_rt")
    inj4ret_setting: Optional[NSB2023Inj4Retsetting] = Field(default=None, alias="Inj4retSetting")
    inj4volperdepth: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Inj4volperdepth")
    inj5_alternating_time: Optional[StrictStr] = Field(default=None, alias="Inj5AlternatingTime")
    inj5_current: Optional[StrictStr] = Field(default=None, alias="Inj5Current")
    inj5_ionto_time: Optional[StrictStr] = Field(default=None, alias="Inj5IontoTime")
    inj5_storage_location: Optional[StrictStr] = Field(default=None, alias="Inj5StorageLocation")
    inj5_type: Optional[NSB2023Inj5Type] = Field(default=None, alias="Inj5Type")
    inj5_virus_strain_rt: Optional[StrictStr] = Field(default=None, alias="Inj5VirusStrain_rt")
    inj5ret_setting: Optional[NSB2023Inj5Retsetting] = Field(default=None, alias="Inj5retSetting")
    inj5volperdepth: Optional[Union[StrictFloat, StrictInt]] = None
    inj6_alternating_time: Optional[StrictStr] = Field(default=None, alias="Inj6AlternatingTime")
    inj6_current: Optional[StrictStr] = Field(default=None, alias="Inj6Current")
    inj6_ionto_time: Optional[StrictStr] = Field(default=None, alias="Inj6IontoTime")
    inj6_storage_location: Optional[StrictStr] = Field(default=None, alias="Inj6StorageLocation")
    inj6_type: Optional[NSB2023Inj6Type] = Field(default=None, alias="Inj6Type")
    inj6_virus_strain_rt: Optional[StrictStr] = Field(default=None, alias="Inj6VirusStrain_rt")
    inj6ret_setting: Optional[NSB2023Inj6Retsetting] = Field(default=None, alias="Inj6retSetting")
    inj6volperdepth: Optional[Union[StrictFloat, StrictInt]] = None
    inj_virus_strain_rt: Optional[StrictStr] = Field(default=None, alias="InjVirusStrain_rt")
    ionto_number_inj1: Optional[NSB2023InitialIontoNumber] = Field(default=None, alias="IontoNumberInj1")
    ionto_number_inj2: Optional[NSB2023FolowUpIontoNumber] = Field(default=None, alias="IontoNumberInj2")
    is_record: Optional[StrictStr] = Field(default=None, alias="_IsRecord")
    iso_x0020_on: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Iso_x0020_On")
    item_child_count: Optional[StrictStr] = Field(default=None, alias="ItemChildCount")
    lab_tracks_x0020_group: Optional[StrictStr] = Field(default=None, alias="LabTracks_x0020_Group")
    lab_tracks_x0020_requestor: Optional[StrictStr] = Field(default=None, alias="LabTracks_x0020_Requestor")
    lab_tracks_x0020_id1: Optional[StrictStr] = Field(default=None, alias="LabTracks_x0020_ID1")
    lims_x0020_required: Optional[NSB2023LimsRequired] = Field(default=None, description="Is LIMS or SLIMS Entry required", alias="LIMs_x0020_Required")
    light_cycle: Optional[Lightcycle] = Field(default=None, alias="LightCycle")
    lims_project: Optional[NSB2023LimsProject] = Field(default=None, alias="LIMSProject")
    lims_taskflow: Optional[NSB2023LimsTaskflow] = Field(default=None, alias="LIMSTaskflow")
    link_title: Optional[StrictStr] = Field(default=None, alias="LinkTitle")
    link_title_no_menu: Optional[StrictStr] = Field(default=None, alias="LinkTitleNoMenu")
    long_requestor_comments: Optional[StrictStr] = Field(default=None, alias="LongRequestorComments")
    ml2nd_inj: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="ML2ndInj")
    modified: Optional[datetime] = Field(default=None, alias="Modified")
    nanoject_number_inj10: Optional[NSB2023InitialNanojectNumber] = Field(default=None, alias="NanojectNumberInj10")
    nanoject_number_inj2: Optional[NSB2023FollowUpNanojectNumber] = Field(default=None, alias="NanojectNumberInj2")
    non_x002d_nsb_x0020_surgeon: Optional[StrictBool] = Field(default=None, alias="Non_x002d_NSB_x0020_Surgeon")
    x0023__x0020_of_x0020_burr_x002: Optional[NSB2023OfBurrHoles] = Field(default=None, alias="_x0023__x0020_of_x0020_Burr_x002")
    pedigree_name: Optional[StrictStr] = Field(default=None, alias="PedigreeName")
    pi: Optional[StrictStr] = Field(default=None, alias="PI")
    procedure: Optional[NSB2023Procedure] = Field(default=None, description="Procedure, Specific T3", alias="Procedure")
    procedure_x0020_family: Optional[NSB2023ProcedureCategory] = Field(default=None, description="Procedure Family T1", alias="Procedure_x0020_Family")
    procedure_x0020_slots: Optional[NSB2023ProcedureSlots] = Field(default=None, description="Sinlge or mutpile surgical slots", alias="Procedure_x0020_Slots")
    procedure_x0020_t2: Optional[NSB2023PhysiologyType] = Field(default=None, description="Procedure Imaging paradigm T2", alias="Procedure_x0020_T2")
    project_id: Optional[NSB2023ProjectId] = Field(default=None, alias="ProjectID")
    protocol: Optional[NSB2023Protocol] = Field(default=None, alias="Protocol")
    ret_setting0: Optional[NSB2023Inj1Retsetting] = Field(default=None, alias="retSetting0")
    ret_setting1: Optional[NSB2023Inj2Retsetting] = Field(default=None, alias="retSetting1")
    round1_inj_isolevel: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Round1InjIsolevel")
    sex: Optional[NSB2023Sex] = Field(default=None, alias="Sex")
    surgery_status: Optional[NSB2023SurgeryStatus] = Field(default=None, alias="SurgeryStatus")
    test1: Optional[StrictStr] = Field(default=None, alias="Test1")
    test_x0020_1st_x0020_round_x0020: Optional[StrictStr] = Field(default=None, alias="TEST_x0020_1st_x0020_Round_x0020")
    thermistor: Optional[NSB2023Thermistor] = Field(default=None, alias="Thermistor")
    title: Optional[StrictStr] = Field(default=None, alias="Title")
    ui_version_string: Optional[StrictStr] = Field(default=None, alias="_UIVersionString")
    virus_x0020_hemisphere: Optional[NSB2023Burr1Hemisphere] = Field(default=None, alias="Virus_x0020_Hemisphere")
    virus_x0020_a_x002f_p: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Virus_x0020_A_x002f_P")
    virus_x0020_d_x002f_v: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Virus_x0020_D_x002f_V")
    virus_x0020_m_x002f_l: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Virus_x0020_M_x002f_L")
    weight_x0020_after_x0020_surgery: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Weight_x0020_after_x0020_Surgery")
    weight_x0020_before_x0020_surger: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="Weight_x0020_before_x0020_Surger")
    work_station1st_injection: Optional[NSB2023FollowUpWorkstation] = Field(default=None, alias="WorkStation1stInjection")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["Age_x0020_at_x0020_Injection", "AIND_x0020_Project_x0020_Name", "AP2ndInj", "AppAuthor", "AppEditor", "Attachments", "Author", "AuthorId", "AuthorLookupId", "EditorId", "EditorLookupId", "Test1LookupId", "TEST_x0020_1st_x0020_Round_x0020LookupId", "Behavior", "Behavior_x0020_Autotrain_x0020_C", "Behavior_x0020_Complete", "Behavior_x0020_Curriculum_x0020_", "behavior_x0020_Destination", "Behavior_x0020_Fiber_x0020_Photo", "Behavior_x0020_First_x0020_Video", "Behavior_x0020_First_x0020_FIP_x", "Behavior_x0020_Platform", "Behavior_x0020_Type", "Behavior_x0020_FIP_x0020_Mode", "Black_x0020_Cement", "Breg2Lamb", "Burr1_x0020_Injection_x0020_Devi", "Burr1_x0020_Perform_x0020_During", "Burr1_x0020_Virus_x0020_Biosafte", "Burr2_x0020_Injection_x0020_Devi", "Burr2_x0020_Perform_x0020_During", "Burr2_x0020_Status", "Burr2_x0020_Virus_x0020_Biosafte", "Burr3_x0020_Injection_x0020_Devi", "Burr3_x0020_Perform_x0020_During", "Burr3_x0020_Status", "Burr3_x0020_Virus_x0020_Biosafet", "Burr3_x0020_A_x002f_P", "Burr3_x0020_D_x002f_V", "Burr3_x0020_M_x002f_L", "Burr4_x0020_Injection_x0020_Devi", "Burr4_x0020_Perform_x0020_During", "Burr4_x0020_Status", "Burr4_x0020_Virus_x0020_Biosafte", "Burr4_x0020_A_x002f_P", "Burr4_x0020_D_x002f_V", "Burr4_x0020_M_x002f_L", "Burr5_x0020_Injection_x0020_Devi", "Burr5_x0020_Perform_x0020_During", "Burr5_x0020_Status", "Burr5_x0020_Virus_x0020_Biosafte", "Burr6_x0020_Injection_x0020_Devi", "Burr6_x0020_Perform_x0020_During", "Burr6_x0020_Status", "Burr6_x0020_Virus_x0020_Biosafte", "Burr_x0020_1_x0020_Fiber_x0020_t", "Burr_x0020_1_x0020_Grid_x0020_Sp", "Burr_x0020_1_x0020_Injectable_x00", "Burr_x0020_1_x0020_Injectable_x01", "Burr_x0020_1_x0020_Injectable_x02", "Burr_x0020_1_x0020_Injectable_x03", "Burr_x0020_1_x0020_Injectable_x04", "Burr_x0020_1_x0020_Injectable_x05", "Burr_x0020_1_x0020_Injectable_x06", "Burr_x0020_1_x0020_Injectable_x0", "Burr_x0020_1_x0020_Intended_x002", "Burr_x0020_1_x0020_Spinal_x0020_", "Burr_x0020_1_x0020_D_x002f_V_x00", "Burr_x0020_1_x0020_DV_x0020_2", "Burr_x0020_1_x0020_intended_x0020", "Burr_x0020_1_x0020_intended_x0021", "Burr_x0020_1_x0020_intended_x0022", "Burr_x0020_1_x0020_intended_x0023", "Burr_x0020_2_x0020_Fiber_x0020_T", "Burr_x0020_2_x0020_Injectable_x00", "Burr_x0020_2_x0020_Injectable_x01", "Burr_x0020_2_x0020_Injectable_x02", "Burr_x0020_2_x0020_Injectable_x03", "Burr_x0020_2_x0020_Injectable_x04", "Burr_x0020_2_x0020_Injectable_x05", "Burr_x0020_2_x0020_Injectable_x06", "Burr_x0020_2_x0020_Injectable_x0", "Burr_x0020_2_x0020_Intended_x002", "Burr_x0020_2_x0020_Spinal_x0020_", "Burr_x0020_2_x0020_D_x002f_V_x000", "Burr_x0020_2_x0020_D_x002f_V_x00", "Burr_x0020_2_x0020_intended_x0020", "Burr_x0020_2_x0020_intended_x0021", "Burr_x0020_2_x0020_intended_x0022", "Burr_x0020_2_x0020_intended_x0023", "Burr_x0020_3_x0020_Angle", "Burr_x0020_3_x0020_Fiber_x0020_T", "Burr_x0020_3_x0020_Hemisphere", "Burr_x0020_3_x0020_Injectable_x00", "Burr_x0020_3_x0020_Injectable_x01", "Burr_x0020_3_x0020_Injectable_x02", "Burr_x0020_3_x0020_Injectable_x03", "Burr_x0020_3_x0020_Injectable_x04", "Burr_x0020_3_x0020_Injectable_x05", "Burr_x0020_3_x0020_Injectable_x06", "Burr_x0020_3_x0020_Injectable_x0", "Burr_x0020_3_x0020_Intended_x002", "Burr_x0020_3_x0020_D_x002f_V_x000", "Burr_x0020_3_x0020_D_x002f_V_x00", "Burr_x0020_3_x0020_intended_x0020", "Burr_x0020_3_x0020_intended_x0021", "Burr_x0020_3_x0020_intended_x0022", "Burr_x0020_3_x0020_intended_x0023", "Burr_x0020_4_x0020_Angle", "Burr_x0020_4_x0020_Fiber_x0020_T", "Burr_x0020_4_x0020_Hemisphere", "Burr_x0020_4_x0020_Injectable_x00", "Burr_x0020_4_x0020_Injectable_x01", "Burr_x0020_4_x0020_Injectable_x02", "Burr_x0020_4_x0020_Injectable_x03", "Burr_x0020_4_x0020_Injectable_x04", "Burr_x0020_4_x0020_Injectable_x05", "Burr_x0020_4_x0020_Injectable_x06", "Burr_x0020_4_x0020_Injectable_x0", "Burr_x0020_4_x0020_Intended_x002", "Burr_x0020_4_x0020_D_x002f_V_x000", "Burr_x0020_4_x0020_D_x002f_V_x00", "Burr_x0020_4_x0020_intended_x0020", "Burr_x0020_4_x0020_intended_x0021", "Burr_x0020_4_x0020_intended_x0022", "Burr_x0020_4_x0020_intended_x0023", "Burr_x0020_5_x0020_Angle", "Burr_x0020_5_x0020_Fiber_x0020_t", "Burr_x0020_5_x0020_Hemisphere", "Burr_x0020_5_x0020_Injectable_x00", "Burr_x0020_5_x0020_Injectable_x01", "Burr_x0020_5_x0020_Injectable_x02", "Burr_x0020_5_x0020_Injectable_x03", "Burr_x0020_5_x0020_Injectable_x04", "Burr_x0020_5_x0020_Injectable_x05", "Burr_x0020_5_x0020_Injectable_x06", "Burr_x0020_5_x0020_Injectable_x0", "Burr_x0020_5_x0020_Intended_x002", "Burr_x0020_5_x0020_A_x002f_P", "Burr_x0020_5_x0020_D_x002f_V_x000", "Burr_x0020_5_x0020_D_x002f_V_x001", "Burr_x0020_5_x0020_D_x002f_V_x00", "Burr_x0020_5_x0020_intended_x0020", "Burr_x0020_5_x0020_intended_x0021", "Burr_x0020_5_x0020_intended_x0022", "Burr_x0020_5_x0020_intended_x0023", "Burr_x0020_5_x0020_M_x002f_L", "Burr_x0020_6_x0020_Angle", "Burr_x0020_6_x0020_Fiber_x0020_t", "Burr_x0020_6_x0020_Hemisphere", "Burr_x0020_6_x0020_Injectable_x00", "Burr_x0020_6_x0020_Injectable_x01", "Burr_x0020_6_x0020_Injectable_x02", "Burr_x0020_6_x0020_Injectable_x03", "Burr_x0020_6_x0020_Injectable_x04", "Burr_x0020_6_x0020_Injectable_x05", "Burr_x0020_6_x0020_Injectable_x06", "Burr_x0020_6_x0020_Injectable_x0", "Burr_x0020_6_x0020_Intended_x002", "Burr_x0020_6_x0020_A_x002f_P", "Burr_x0020_6_x0020_D_x002f_V_x000", "Burr_x0020_6_x0020_D_x002f_V_x001", "Burr_x0020_6_x0020_D_x002f_V_x00", "Burr_x0020_6_x0020_intended_x0020", "Burr_x0020_6_x0020_intended_x0021", "Burr_x0020_6_x0020_intended_x0022", "Burr_x0020_6_x0020_intended_x0023", "Burr_x0020_6_x0020_M_x002f_L", "Burr_x0020_Hole_x0020_1_x0020_st", "Burr_x0020_hole_x0020_1", "Burr_x0020_hole_x0020_2", "Burr_x0020_hole_x0020_3", "Burr_x0020_hole_x0020_4", "Burr_x0020_hole_x0020_5", "Burr_x0020_hole_x0020_6", "Care_x0020_Moduele", "_ColorTag", "ComCoplanar", "ComSinusbleed", "ComSwelling", "ComplianceAssetId", "ContentType", "Contusion", "Craniotomy_x0020_Perform_x0020_D", "CraniotomyType", "Created", "Date1stInjection", "Date_x0020_of_x0020_Birth", "Date_x0020_of_x0020_Surgery", "DateRangeStart", "DocIcon", "DV2ndInj", "Edit", "Editor", "Fiber_x0020_Implant1_x0020_Lengt", "Fiber_x0020_Implant2_x0020_Lengt", "Fiber_x0020_Implant3_x0020_Lengt", "Fiber_x0020_Implant3_x0020_D_x00", "Fiber_x0020_Implant4_x0020_Lengt", "Fiber_x0020_Implant4_x0020_D_x00", "Fiber_x0020_Implant5_x0020_Lengt", "Fiber_x0020_Implant5_x0020_D_x00", "Fiber_x0020_Implant6_x0020_Lengt", "Fiber_x0020_Implant6_x0020_D_x00", "FiberImplant1DV", "FiberImplant2DV", "FirstInjRecovery", "FirstInjectionIsoDuration", "FirstInjectionWeightAfter", "FirstInjectionWeightBefor", "FolderChildCount", "Headpost", "Headpost_x0020_Perform_x0020_Dur", "HeadpostType", "Hemisphere2ndInj", "HPIsoLevel", "HPRecovery", "HPSurgeonComments", "HpWorkStation", "IACUC_x0020_Protocol_x0020__x002", "ID", "ImplantIDCoverslipType", "Inj1AlternatingTime", "Inj1Angle_v2", "Inj1Current", "Inj1IontoTime", "Inj1StorageLocation", "Inj1Type", "Inj1VirusStrain_rt", "inj1volperdepth", "Inj2AlternatingTime", "Inj2Angle_v2", "Inj2Current", "Inj2IontoTime", "Inj2StorageLocation", "Inj2Type", "Inj2VirusStrain_rt", "inj2volperdepth", "Inj3AlternatingTime", "Inj3Current", "Inj3IontoTime", "Inj3StorageLocation", "Inj3Type", "Inj3retSetting", "Inj3volperdepth", "Inj4AlternatingTime", "Inj4Current", "Inj4IontoTime", "Inj4StorageLocation", "Inj4Type", "Inj4VirusStrain_rt", "Inj4retSetting", "Inj4volperdepth", "Inj5AlternatingTime", "Inj5Current", "Inj5IontoTime", "Inj5StorageLocation", "Inj5Type", "Inj5VirusStrain_rt", "Inj5retSetting", "inj5volperdepth", "Inj6AlternatingTime", "Inj6Current", "Inj6IontoTime", "Inj6StorageLocation", "Inj6Type", "Inj6VirusStrain_rt", "Inj6retSetting", "inj6volperdepth", "InjVirusStrain_rt", "IontoNumberInj1", "IontoNumberInj2", "_IsRecord", "Iso_x0020_On", "ItemChildCount", "LabTracks_x0020_Group", "LabTracks_x0020_Requestor", "LabTracks_x0020_ID1", "LIMs_x0020_Required", "LightCycle", "LIMSProject", "LIMSTaskflow", "LinkTitle", "LinkTitleNoMenu", "LongRequestorComments", "ML2ndInj", "Modified", "NanojectNumberInj10", "NanojectNumberInj2", "Non_x002d_NSB_x0020_Surgeon", "_x0023__x0020_of_x0020_Burr_x002", "PedigreeName", "PI", "Procedure", "Procedure_x0020_Family", "Procedure_x0020_Slots", "Procedure_x0020_T2", "ProjectID", "Protocol", "retSetting0", "retSetting1", "Round1InjIsolevel", "Sex", "SurgeryStatus", "Test1", "TEST_x0020_1st_x0020_Round_x0020", "Thermistor", "Title", "_UIVersionString", "Virus_x0020_Hemisphere", "Virus_x0020_A_x002f_P", "Virus_x0020_D_x002f_V", "Virus_x0020_M_x002f_L", "Weight_x0020_after_x0020_Surgery", "Weight_x0020_before_x0020_Surger", "WorkStation1stInjection"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of NSB2023List from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        # set to None if age_x0020_at_x0020_injection (nullable) is None
        # and model_fields_set contains the field
        if self.age_x0020_at_x0020_injection is None and "age_x0020_at_x0020_injection" in self.model_fields_set:
            _dict['Age_x0020_at_x0020_Injection'] = None

        # set to None if ap2nd_inj (nullable) is None
        # and model_fields_set contains the field
        if self.ap2nd_inj is None and "ap2nd_inj" in self.model_fields_set:
            _dict['AP2ndInj'] = None

        # set to None if app_author (nullable) is None
        # and model_fields_set contains the field
        if self.app_author is None and "app_author" in self.model_fields_set:
            _dict['AppAuthor'] = None

        # set to None if app_editor (nullable) is None
        # and model_fields_set contains the field
        if self.app_editor is None and "app_editor" in self.model_fields_set:
            _dict['AppEditor'] = None

        # set to None if attachments (nullable) is None
        # and model_fields_set contains the field
        if self.attachments is None and "attachments" in self.model_fields_set:
            _dict['Attachments'] = None

        # set to None if author (nullable) is None
        # and model_fields_set contains the field
        if self.author is None and "author" in self.model_fields_set:
            _dict['Author'] = None

        # set to None if author_id (nullable) is None
        # and model_fields_set contains the field
        if self.author_id is None and "author_id" in self.model_fields_set:
            _dict['AuthorId'] = None

        # set to None if author_lookup_id (nullable) is None
        # and model_fields_set contains the field
        if self.author_lookup_id is None and "author_lookup_id" in self.model_fields_set:
            _dict['AuthorLookupId'] = None

        # set to None if editor_id (nullable) is None
        # and model_fields_set contains the field
        if self.editor_id is None and "editor_id" in self.model_fields_set:
            _dict['EditorId'] = None

        # set to None if editor_lookup_id (nullable) is None
        # and model_fields_set contains the field
        if self.editor_lookup_id is None and "editor_lookup_id" in self.model_fields_set:
            _dict['EditorLookupId'] = None

        # set to None if test1_lookup_id (nullable) is None
        # and model_fields_set contains the field
        if self.test1_lookup_id is None and "test1_lookup_id" in self.model_fields_set:
            _dict['Test1LookupId'] = None

        # set to None if test_x0020_1st_x0020_round_x0020_lookup_id (nullable) is None
        # and model_fields_set contains the field
        if self.test_x0020_1st_x0020_round_x0020_lookup_id is None and "test_x0020_1st_x0020_round_x0020_lookup_id" in self.model_fields_set:
            _dict['TEST_x0020_1st_x0020_Round_x0020LookupId'] = None

        # set to None if behavior_x0020_complete (nullable) is None
        # and model_fields_set contains the field
        if self.behavior_x0020_complete is None and "behavior_x0020_complete" in self.model_fields_set:
            _dict['Behavior_x0020_Complete'] = None

        # set to None if breg2_lamb (nullable) is None
        # and model_fields_set contains the field
        if self.breg2_lamb is None and "breg2_lamb" in self.model_fields_set:
            _dict['Breg2Lamb'] = None

        # set to None if burr3_x0020_a_x002f_p (nullable) is None
        # and model_fields_set contains the field
        if self.burr3_x0020_a_x002f_p is None and "burr3_x0020_a_x002f_p" in self.model_fields_set:
            _dict['Burr3_x0020_A_x002f_P'] = None

        # set to None if burr3_x0020_d_x002f_v (nullable) is None
        # and model_fields_set contains the field
        if self.burr3_x0020_d_x002f_v is None and "burr3_x0020_d_x002f_v" in self.model_fields_set:
            _dict['Burr3_x0020_D_x002f_V'] = None

        # set to None if burr3_x0020_m_x002f_l (nullable) is None
        # and model_fields_set contains the field
        if self.burr3_x0020_m_x002f_l is None and "burr3_x0020_m_x002f_l" in self.model_fields_set:
            _dict['Burr3_x0020_M_x002f_L'] = None

        # set to None if burr4_x0020_a_x002f_p (nullable) is None
        # and model_fields_set contains the field
        if self.burr4_x0020_a_x002f_p is None and "burr4_x0020_a_x002f_p" in self.model_fields_set:
            _dict['Burr4_x0020_A_x002f_P'] = None

        # set to None if burr4_x0020_d_x002f_v (nullable) is None
        # and model_fields_set contains the field
        if self.burr4_x0020_d_x002f_v is None and "burr4_x0020_d_x002f_v" in self.model_fields_set:
            _dict['Burr4_x0020_D_x002f_V'] = None

        # set to None if burr4_x0020_m_x002f_l (nullable) is None
        # and model_fields_set contains the field
        if self.burr4_x0020_m_x002f_l is None and "burr4_x0020_m_x002f_l" in self.model_fields_set:
            _dict['Burr4_x0020_M_x002f_L'] = None

        # set to None if burr_x0020_1_x0020_grid_x0020_sp (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_1_x0020_grid_x0020_sp is None and "burr_x0020_1_x0020_grid_x0020_sp" in self.model_fields_set:
            _dict['Burr_x0020_1_x0020_Grid_x0020_Sp'] = None

        # set to None if burr_x0020_1_x0020_injectable_x00 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_1_x0020_injectable_x00 is None and "burr_x0020_1_x0020_injectable_x00" in self.model_fields_set:
            _dict['Burr_x0020_1_x0020_Injectable_x00'] = None

        # set to None if burr_x0020_1_x0020_injectable_x01 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_1_x0020_injectable_x01 is None and "burr_x0020_1_x0020_injectable_x01" in self.model_fields_set:
            _dict['Burr_x0020_1_x0020_Injectable_x01'] = None

        # set to None if burr_x0020_1_x0020_injectable_x02 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_1_x0020_injectable_x02 is None and "burr_x0020_1_x0020_injectable_x02" in self.model_fields_set:
            _dict['Burr_x0020_1_x0020_Injectable_x02'] = None

        # set to None if burr_x0020_1_x0020_injectable_x03 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_1_x0020_injectable_x03 is None and "burr_x0020_1_x0020_injectable_x03" in self.model_fields_set:
            _dict['Burr_x0020_1_x0020_Injectable_x03'] = None

        # set to None if burr_x0020_1_x0020_injectable_x04 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_1_x0020_injectable_x04 is None and "burr_x0020_1_x0020_injectable_x04" in self.model_fields_set:
            _dict['Burr_x0020_1_x0020_Injectable_x04'] = None

        # set to None if burr_x0020_1_x0020_injectable_x05 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_1_x0020_injectable_x05 is None and "burr_x0020_1_x0020_injectable_x05" in self.model_fields_set:
            _dict['Burr_x0020_1_x0020_Injectable_x05'] = None

        # set to None if burr_x0020_1_x0020_injectable_x06 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_1_x0020_injectable_x06 is None and "burr_x0020_1_x0020_injectable_x06" in self.model_fields_set:
            _dict['Burr_x0020_1_x0020_Injectable_x06'] = None

        # set to None if burr_x0020_1_x0020_injectable_x0 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_1_x0020_injectable_x0 is None and "burr_x0020_1_x0020_injectable_x0" in self.model_fields_set:
            _dict['Burr_x0020_1_x0020_Injectable_x0'] = None

        # set to None if burr_x0020_1_x0020_intended_x002 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_1_x0020_intended_x002 is None and "burr_x0020_1_x0020_intended_x002" in self.model_fields_set:
            _dict['Burr_x0020_1_x0020_Intended_x002'] = None

        # set to None if burr_x0020_1_x0020_d_x002f_v_x00 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_1_x0020_d_x002f_v_x00 is None and "burr_x0020_1_x0020_d_x002f_v_x00" in self.model_fields_set:
            _dict['Burr_x0020_1_x0020_D_x002f_V_x00'] = None

        # set to None if burr_x0020_1_x0020_dv_x0020_2 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_1_x0020_dv_x0020_2 is None and "burr_x0020_1_x0020_dv_x0020_2" in self.model_fields_set:
            _dict['Burr_x0020_1_x0020_DV_x0020_2'] = None

        # set to None if burr_x0020_2_x0020_injectable_x00 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_2_x0020_injectable_x00 is None and "burr_x0020_2_x0020_injectable_x00" in self.model_fields_set:
            _dict['Burr_x0020_2_x0020_Injectable_x00'] = None

        # set to None if burr_x0020_2_x0020_injectable_x01 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_2_x0020_injectable_x01 is None and "burr_x0020_2_x0020_injectable_x01" in self.model_fields_set:
            _dict['Burr_x0020_2_x0020_Injectable_x01'] = None

        # set to None if burr_x0020_2_x0020_injectable_x02 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_2_x0020_injectable_x02 is None and "burr_x0020_2_x0020_injectable_x02" in self.model_fields_set:
            _dict['Burr_x0020_2_x0020_Injectable_x02'] = None

        # set to None if burr_x0020_2_x0020_injectable_x03 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_2_x0020_injectable_x03 is None and "burr_x0020_2_x0020_injectable_x03" in self.model_fields_set:
            _dict['Burr_x0020_2_x0020_Injectable_x03'] = None

        # set to None if burr_x0020_2_x0020_injectable_x04 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_2_x0020_injectable_x04 is None and "burr_x0020_2_x0020_injectable_x04" in self.model_fields_set:
            _dict['Burr_x0020_2_x0020_Injectable_x04'] = None

        # set to None if burr_x0020_2_x0020_injectable_x05 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_2_x0020_injectable_x05 is None and "burr_x0020_2_x0020_injectable_x05" in self.model_fields_set:
            _dict['Burr_x0020_2_x0020_Injectable_x05'] = None

        # set to None if burr_x0020_2_x0020_injectable_x06 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_2_x0020_injectable_x06 is None and "burr_x0020_2_x0020_injectable_x06" in self.model_fields_set:
            _dict['Burr_x0020_2_x0020_Injectable_x06'] = None

        # set to None if burr_x0020_2_x0020_injectable_x0 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_2_x0020_injectable_x0 is None and "burr_x0020_2_x0020_injectable_x0" in self.model_fields_set:
            _dict['Burr_x0020_2_x0020_Injectable_x0'] = None

        # set to None if burr_x0020_2_x0020_intended_x002 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_2_x0020_intended_x002 is None and "burr_x0020_2_x0020_intended_x002" in self.model_fields_set:
            _dict['Burr_x0020_2_x0020_Intended_x002'] = None

        # set to None if burr_x0020_2_x0020_d_x002f_v_x000 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_2_x0020_d_x002f_v_x000 is None and "burr_x0020_2_x0020_d_x002f_v_x000" in self.model_fields_set:
            _dict['Burr_x0020_2_x0020_D_x002f_V_x000'] = None

        # set to None if burr_x0020_2_x0020_d_x002f_v_x00 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_2_x0020_d_x002f_v_x00 is None and "burr_x0020_2_x0020_d_x002f_v_x00" in self.model_fields_set:
            _dict['Burr_x0020_2_x0020_D_x002f_V_x00'] = None

        # set to None if burr_x0020_3_x0020_angle (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_3_x0020_angle is None and "burr_x0020_3_x0020_angle" in self.model_fields_set:
            _dict['Burr_x0020_3_x0020_Angle'] = None

        # set to None if burr_x0020_3_x0020_injectable_x00 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_3_x0020_injectable_x00 is None and "burr_x0020_3_x0020_injectable_x00" in self.model_fields_set:
            _dict['Burr_x0020_3_x0020_Injectable_x00'] = None

        # set to None if burr_x0020_3_x0020_injectable_x01 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_3_x0020_injectable_x01 is None and "burr_x0020_3_x0020_injectable_x01" in self.model_fields_set:
            _dict['Burr_x0020_3_x0020_Injectable_x01'] = None

        # set to None if burr_x0020_3_x0020_injectable_x02 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_3_x0020_injectable_x02 is None and "burr_x0020_3_x0020_injectable_x02" in self.model_fields_set:
            _dict['Burr_x0020_3_x0020_Injectable_x02'] = None

        # set to None if burr_x0020_3_x0020_injectable_x03 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_3_x0020_injectable_x03 is None and "burr_x0020_3_x0020_injectable_x03" in self.model_fields_set:
            _dict['Burr_x0020_3_x0020_Injectable_x03'] = None

        # set to None if burr_x0020_3_x0020_injectable_x04 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_3_x0020_injectable_x04 is None and "burr_x0020_3_x0020_injectable_x04" in self.model_fields_set:
            _dict['Burr_x0020_3_x0020_Injectable_x04'] = None

        # set to None if burr_x0020_3_x0020_injectable_x05 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_3_x0020_injectable_x05 is None and "burr_x0020_3_x0020_injectable_x05" in self.model_fields_set:
            _dict['Burr_x0020_3_x0020_Injectable_x05'] = None

        # set to None if burr_x0020_3_x0020_injectable_x06 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_3_x0020_injectable_x06 is None and "burr_x0020_3_x0020_injectable_x06" in self.model_fields_set:
            _dict['Burr_x0020_3_x0020_Injectable_x06'] = None

        # set to None if burr_x0020_3_x0020_injectable_x0 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_3_x0020_injectable_x0 is None and "burr_x0020_3_x0020_injectable_x0" in self.model_fields_set:
            _dict['Burr_x0020_3_x0020_Injectable_x0'] = None

        # set to None if burr_x0020_3_x0020_intended_x002 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_3_x0020_intended_x002 is None and "burr_x0020_3_x0020_intended_x002" in self.model_fields_set:
            _dict['Burr_x0020_3_x0020_Intended_x002'] = None

        # set to None if burr_x0020_3_x0020_d_x002f_v_x000 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_3_x0020_d_x002f_v_x000 is None and "burr_x0020_3_x0020_d_x002f_v_x000" in self.model_fields_set:
            _dict['Burr_x0020_3_x0020_D_x002f_V_x000'] = None

        # set to None if burr_x0020_3_x0020_d_x002f_v_x00 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_3_x0020_d_x002f_v_x00 is None and "burr_x0020_3_x0020_d_x002f_v_x00" in self.model_fields_set:
            _dict['Burr_x0020_3_x0020_D_x002f_V_x00'] = None

        # set to None if burr_x0020_4_x0020_angle (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_4_x0020_angle is None and "burr_x0020_4_x0020_angle" in self.model_fields_set:
            _dict['Burr_x0020_4_x0020_Angle'] = None

        # set to None if burr_x0020_4_x0020_injectable_x00 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_4_x0020_injectable_x00 is None and "burr_x0020_4_x0020_injectable_x00" in self.model_fields_set:
            _dict['Burr_x0020_4_x0020_Injectable_x00'] = None

        # set to None if burr_x0020_4_x0020_injectable_x01 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_4_x0020_injectable_x01 is None and "burr_x0020_4_x0020_injectable_x01" in self.model_fields_set:
            _dict['Burr_x0020_4_x0020_Injectable_x01'] = None

        # set to None if burr_x0020_4_x0020_injectable_x02 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_4_x0020_injectable_x02 is None and "burr_x0020_4_x0020_injectable_x02" in self.model_fields_set:
            _dict['Burr_x0020_4_x0020_Injectable_x02'] = None

        # set to None if burr_x0020_4_x0020_injectable_x03 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_4_x0020_injectable_x03 is None and "burr_x0020_4_x0020_injectable_x03" in self.model_fields_set:
            _dict['Burr_x0020_4_x0020_Injectable_x03'] = None

        # set to None if burr_x0020_4_x0020_injectable_x04 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_4_x0020_injectable_x04 is None and "burr_x0020_4_x0020_injectable_x04" in self.model_fields_set:
            _dict['Burr_x0020_4_x0020_Injectable_x04'] = None

        # set to None if burr_x0020_4_x0020_injectable_x05 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_4_x0020_injectable_x05 is None and "burr_x0020_4_x0020_injectable_x05" in self.model_fields_set:
            _dict['Burr_x0020_4_x0020_Injectable_x05'] = None

        # set to None if burr_x0020_4_x0020_injectable_x06 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_4_x0020_injectable_x06 is None and "burr_x0020_4_x0020_injectable_x06" in self.model_fields_set:
            _dict['Burr_x0020_4_x0020_Injectable_x06'] = None

        # set to None if burr_x0020_4_x0020_injectable_x0 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_4_x0020_injectable_x0 is None and "burr_x0020_4_x0020_injectable_x0" in self.model_fields_set:
            _dict['Burr_x0020_4_x0020_Injectable_x0'] = None

        # set to None if burr_x0020_4_x0020_intended_x002 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_4_x0020_intended_x002 is None and "burr_x0020_4_x0020_intended_x002" in self.model_fields_set:
            _dict['Burr_x0020_4_x0020_Intended_x002'] = None

        # set to None if burr_x0020_4_x0020_d_x002f_v_x000 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_4_x0020_d_x002f_v_x000 is None and "burr_x0020_4_x0020_d_x002f_v_x000" in self.model_fields_set:
            _dict['Burr_x0020_4_x0020_D_x002f_V_x000'] = None

        # set to None if burr_x0020_4_x0020_d_x002f_v_x00 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_4_x0020_d_x002f_v_x00 is None and "burr_x0020_4_x0020_d_x002f_v_x00" in self.model_fields_set:
            _dict['Burr_x0020_4_x0020_D_x002f_V_x00'] = None

        # set to None if burr_x0020_5_x0020_angle (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_5_x0020_angle is None and "burr_x0020_5_x0020_angle" in self.model_fields_set:
            _dict['Burr_x0020_5_x0020_Angle'] = None

        # set to None if burr_x0020_5_x0020_injectable_x00 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_5_x0020_injectable_x00 is None and "burr_x0020_5_x0020_injectable_x00" in self.model_fields_set:
            _dict['Burr_x0020_5_x0020_Injectable_x00'] = None

        # set to None if burr_x0020_5_x0020_injectable_x01 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_5_x0020_injectable_x01 is None and "burr_x0020_5_x0020_injectable_x01" in self.model_fields_set:
            _dict['Burr_x0020_5_x0020_Injectable_x01'] = None

        # set to None if burr_x0020_5_x0020_injectable_x02 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_5_x0020_injectable_x02 is None and "burr_x0020_5_x0020_injectable_x02" in self.model_fields_set:
            _dict['Burr_x0020_5_x0020_Injectable_x02'] = None

        # set to None if burr_x0020_5_x0020_injectable_x03 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_5_x0020_injectable_x03 is None and "burr_x0020_5_x0020_injectable_x03" in self.model_fields_set:
            _dict['Burr_x0020_5_x0020_Injectable_x03'] = None

        # set to None if burr_x0020_5_x0020_injectable_x04 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_5_x0020_injectable_x04 is None and "burr_x0020_5_x0020_injectable_x04" in self.model_fields_set:
            _dict['Burr_x0020_5_x0020_Injectable_x04'] = None

        # set to None if burr_x0020_5_x0020_injectable_x05 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_5_x0020_injectable_x05 is None and "burr_x0020_5_x0020_injectable_x05" in self.model_fields_set:
            _dict['Burr_x0020_5_x0020_Injectable_x05'] = None

        # set to None if burr_x0020_5_x0020_injectable_x06 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_5_x0020_injectable_x06 is None and "burr_x0020_5_x0020_injectable_x06" in self.model_fields_set:
            _dict['Burr_x0020_5_x0020_Injectable_x06'] = None

        # set to None if burr_x0020_5_x0020_injectable_x0 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_5_x0020_injectable_x0 is None and "burr_x0020_5_x0020_injectable_x0" in self.model_fields_set:
            _dict['Burr_x0020_5_x0020_Injectable_x0'] = None

        # set to None if burr_x0020_5_x0020_intended_x002 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_5_x0020_intended_x002 is None and "burr_x0020_5_x0020_intended_x002" in self.model_fields_set:
            _dict['Burr_x0020_5_x0020_Intended_x002'] = None

        # set to None if burr_x0020_5_x0020_a_x002f_p (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_5_x0020_a_x002f_p is None and "burr_x0020_5_x0020_a_x002f_p" in self.model_fields_set:
            _dict['Burr_x0020_5_x0020_A_x002f_P'] = None

        # set to None if burr_x0020_5_x0020_d_x002f_v_x000 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_5_x0020_d_x002f_v_x000 is None and "burr_x0020_5_x0020_d_x002f_v_x000" in self.model_fields_set:
            _dict['Burr_x0020_5_x0020_D_x002f_V_x000'] = None

        # set to None if burr_x0020_5_x0020_d_x002f_v_x001 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_5_x0020_d_x002f_v_x001 is None and "burr_x0020_5_x0020_d_x002f_v_x001" in self.model_fields_set:
            _dict['Burr_x0020_5_x0020_D_x002f_V_x001'] = None

        # set to None if burr_x0020_5_x0020_d_x002f_v_x00 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_5_x0020_d_x002f_v_x00 is None and "burr_x0020_5_x0020_d_x002f_v_x00" in self.model_fields_set:
            _dict['Burr_x0020_5_x0020_D_x002f_V_x00'] = None

        # set to None if burr_x0020_5_x0020_m_x002f_l (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_5_x0020_m_x002f_l is None and "burr_x0020_5_x0020_m_x002f_l" in self.model_fields_set:
            _dict['Burr_x0020_5_x0020_M_x002f_L'] = None

        # set to None if burr_x0020_6_x0020_angle (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_6_x0020_angle is None and "burr_x0020_6_x0020_angle" in self.model_fields_set:
            _dict['Burr_x0020_6_x0020_Angle'] = None

        # set to None if burr_x0020_6_x0020_injectable_x00 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_6_x0020_injectable_x00 is None and "burr_x0020_6_x0020_injectable_x00" in self.model_fields_set:
            _dict['Burr_x0020_6_x0020_Injectable_x00'] = None

        # set to None if burr_x0020_6_x0020_injectable_x01 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_6_x0020_injectable_x01 is None and "burr_x0020_6_x0020_injectable_x01" in self.model_fields_set:
            _dict['Burr_x0020_6_x0020_Injectable_x01'] = None

        # set to None if burr_x0020_6_x0020_injectable_x02 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_6_x0020_injectable_x02 is None and "burr_x0020_6_x0020_injectable_x02" in self.model_fields_set:
            _dict['Burr_x0020_6_x0020_Injectable_x02'] = None

        # set to None if burr_x0020_6_x0020_injectable_x03 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_6_x0020_injectable_x03 is None and "burr_x0020_6_x0020_injectable_x03" in self.model_fields_set:
            _dict['Burr_x0020_6_x0020_Injectable_x03'] = None

        # set to None if burr_x0020_6_x0020_injectable_x04 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_6_x0020_injectable_x04 is None and "burr_x0020_6_x0020_injectable_x04" in self.model_fields_set:
            _dict['Burr_x0020_6_x0020_Injectable_x04'] = None

        # set to None if burr_x0020_6_x0020_injectable_x05 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_6_x0020_injectable_x05 is None and "burr_x0020_6_x0020_injectable_x05" in self.model_fields_set:
            _dict['Burr_x0020_6_x0020_Injectable_x05'] = None

        # set to None if burr_x0020_6_x0020_injectable_x06 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_6_x0020_injectable_x06 is None and "burr_x0020_6_x0020_injectable_x06" in self.model_fields_set:
            _dict['Burr_x0020_6_x0020_Injectable_x06'] = None

        # set to None if burr_x0020_6_x0020_injectable_x0 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_6_x0020_injectable_x0 is None and "burr_x0020_6_x0020_injectable_x0" in self.model_fields_set:
            _dict['Burr_x0020_6_x0020_Injectable_x0'] = None

        # set to None if burr_x0020_6_x0020_intended_x002 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_6_x0020_intended_x002 is None and "burr_x0020_6_x0020_intended_x002" in self.model_fields_set:
            _dict['Burr_x0020_6_x0020_Intended_x002'] = None

        # set to None if burr_x0020_6_x0020_a_x002f_p (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_6_x0020_a_x002f_p is None and "burr_x0020_6_x0020_a_x002f_p" in self.model_fields_set:
            _dict['Burr_x0020_6_x0020_A_x002f_P'] = None

        # set to None if burr_x0020_6_x0020_d_x002f_v_x000 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_6_x0020_d_x002f_v_x000 is None and "burr_x0020_6_x0020_d_x002f_v_x000" in self.model_fields_set:
            _dict['Burr_x0020_6_x0020_D_x002f_V_x000'] = None

        # set to None if burr_x0020_6_x0020_d_x002f_v_x001 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_6_x0020_d_x002f_v_x001 is None and "burr_x0020_6_x0020_d_x002f_v_x001" in self.model_fields_set:
            _dict['Burr_x0020_6_x0020_D_x002f_V_x001'] = None

        # set to None if burr_x0020_6_x0020_d_x002f_v_x00 (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_6_x0020_d_x002f_v_x00 is None and "burr_x0020_6_x0020_d_x002f_v_x00" in self.model_fields_set:
            _dict['Burr_x0020_6_x0020_D_x002f_V_x00'] = None

        # set to None if burr_x0020_6_x0020_m_x002f_l (nullable) is None
        # and model_fields_set contains the field
        if self.burr_x0020_6_x0020_m_x002f_l is None and "burr_x0020_6_x0020_m_x002f_l" in self.model_fields_set:
            _dict['Burr_x0020_6_x0020_M_x002f_L'] = None

        # set to None if color_tag (nullable) is None
        # and model_fields_set contains the field
        if self.color_tag is None and "color_tag" in self.model_fields_set:
            _dict['_ColorTag'] = None

        # set to None if compliance_asset_id (nullable) is None
        # and model_fields_set contains the field
        if self.compliance_asset_id is None and "compliance_asset_id" in self.model_fields_set:
            _dict['ComplianceAssetId'] = None

        # set to None if content_type (nullable) is None
        # and model_fields_set contains the field
        if self.content_type is None and "content_type" in self.model_fields_set:
            _dict['ContentType'] = None

        # set to None if created (nullable) is None
        # and model_fields_set contains the field
        if self.created is None and "created" in self.model_fields_set:
            _dict['Created'] = None

        # set to None if date1st_injection (nullable) is None
        # and model_fields_set contains the field
        if self.date1st_injection is None and "date1st_injection" in self.model_fields_set:
            _dict['Date1stInjection'] = None

        # set to None if date_x0020_of_x0020_birth (nullable) is None
        # and model_fields_set contains the field
        if self.date_x0020_of_x0020_birth is None and "date_x0020_of_x0020_birth" in self.model_fields_set:
            _dict['Date_x0020_of_x0020_Birth'] = None

        # set to None if date_x0020_of_x0020_surgery (nullable) is None
        # and model_fields_set contains the field
        if self.date_x0020_of_x0020_surgery is None and "date_x0020_of_x0020_surgery" in self.model_fields_set:
            _dict['Date_x0020_of_x0020_Surgery'] = None

        # set to None if date_range_start (nullable) is None
        # and model_fields_set contains the field
        if self.date_range_start is None and "date_range_start" in self.model_fields_set:
            _dict['DateRangeStart'] = None

        # set to None if doc_icon (nullable) is None
        # and model_fields_set contains the field
        if self.doc_icon is None and "doc_icon" in self.model_fields_set:
            _dict['DocIcon'] = None

        # set to None if dv2nd_inj (nullable) is None
        # and model_fields_set contains the field
        if self.dv2nd_inj is None and "dv2nd_inj" in self.model_fields_set:
            _dict['DV2ndInj'] = None

        # set to None if edit (nullable) is None
        # and model_fields_set contains the field
        if self.edit is None and "edit" in self.model_fields_set:
            _dict['Edit'] = None

        # set to None if editor (nullable) is None
        # and model_fields_set contains the field
        if self.editor is None and "editor" in self.model_fields_set:
            _dict['Editor'] = None

        # set to None if fiber_x0020_implant3_x0020_d_x00 (nullable) is None
        # and model_fields_set contains the field
        if self.fiber_x0020_implant3_x0020_d_x00 is None and "fiber_x0020_implant3_x0020_d_x00" in self.model_fields_set:
            _dict['Fiber_x0020_Implant3_x0020_D_x00'] = None

        # set to None if fiber_x0020_implant4_x0020_d_x00 (nullable) is None
        # and model_fields_set contains the field
        if self.fiber_x0020_implant4_x0020_d_x00 is None and "fiber_x0020_implant4_x0020_d_x00" in self.model_fields_set:
            _dict['Fiber_x0020_Implant4_x0020_D_x00'] = None

        # set to None if fiber_x0020_implant5_x0020_d_x00 (nullable) is None
        # and model_fields_set contains the field
        if self.fiber_x0020_implant5_x0020_d_x00 is None and "fiber_x0020_implant5_x0020_d_x00" in self.model_fields_set:
            _dict['Fiber_x0020_Implant5_x0020_D_x00'] = None

        # set to None if fiber_x0020_implant6_x0020_d_x00 (nullable) is None
        # and model_fields_set contains the field
        if self.fiber_x0020_implant6_x0020_d_x00 is None and "fiber_x0020_implant6_x0020_d_x00" in self.model_fields_set:
            _dict['Fiber_x0020_Implant6_x0020_D_x00'] = None

        # set to None if fiber_implant1_dv (nullable) is None
        # and model_fields_set contains the field
        if self.fiber_implant1_dv is None and "fiber_implant1_dv" in self.model_fields_set:
            _dict['FiberImplant1DV'] = None

        # set to None if fiber_implant2_dv (nullable) is None
        # and model_fields_set contains the field
        if self.fiber_implant2_dv is None and "fiber_implant2_dv" in self.model_fields_set:
            _dict['FiberImplant2DV'] = None

        # set to None if first_inj_recovery (nullable) is None
        # and model_fields_set contains the field
        if self.first_inj_recovery is None and "first_inj_recovery" in self.model_fields_set:
            _dict['FirstInjRecovery'] = None

        # set to None if first_injection_iso_duration (nullable) is None
        # and model_fields_set contains the field
        if self.first_injection_iso_duration is None and "first_injection_iso_duration" in self.model_fields_set:
            _dict['FirstInjectionIsoDuration'] = None

        # set to None if first_injection_weight_after (nullable) is None
        # and model_fields_set contains the field
        if self.first_injection_weight_after is None and "first_injection_weight_after" in self.model_fields_set:
            _dict['FirstInjectionWeightAfter'] = None

        # set to None if first_injection_weight_befor (nullable) is None
        # and model_fields_set contains the field
        if self.first_injection_weight_befor is None and "first_injection_weight_befor" in self.model_fields_set:
            _dict['FirstInjectionWeightBefor'] = None

        # set to None if folder_child_count (nullable) is None
        # and model_fields_set contains the field
        if self.folder_child_count is None and "folder_child_count" in self.model_fields_set:
            _dict['FolderChildCount'] = None

        # set to None if hp_iso_level (nullable) is None
        # and model_fields_set contains the field
        if self.hp_iso_level is None and "hp_iso_level" in self.model_fields_set:
            _dict['HPIsoLevel'] = None

        # set to None if hp_recovery (nullable) is None
        # and model_fields_set contains the field
        if self.hp_recovery is None and "hp_recovery" in self.model_fields_set:
            _dict['HPRecovery'] = None

        # set to None if hp_surgeon_comments (nullable) is None
        # and model_fields_set contains the field
        if self.hp_surgeon_comments is None and "hp_surgeon_comments" in self.model_fields_set:
            _dict['HPSurgeonComments'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['ID'] = None

        # set to None if inj1_alternating_time (nullable) is None
        # and model_fields_set contains the field
        if self.inj1_alternating_time is None and "inj1_alternating_time" in self.model_fields_set:
            _dict['Inj1AlternatingTime'] = None

        # set to None if inj1_angle_v2 (nullable) is None
        # and model_fields_set contains the field
        if self.inj1_angle_v2 is None and "inj1_angle_v2" in self.model_fields_set:
            _dict['Inj1Angle_v2'] = None

        # set to None if inj1_current (nullable) is None
        # and model_fields_set contains the field
        if self.inj1_current is None and "inj1_current" in self.model_fields_set:
            _dict['Inj1Current'] = None

        # set to None if inj1_ionto_time (nullable) is None
        # and model_fields_set contains the field
        if self.inj1_ionto_time is None and "inj1_ionto_time" in self.model_fields_set:
            _dict['Inj1IontoTime'] = None

        # set to None if inj1_storage_location (nullable) is None
        # and model_fields_set contains the field
        if self.inj1_storage_location is None and "inj1_storage_location" in self.model_fields_set:
            _dict['Inj1StorageLocation'] = None

        # set to None if inj1_virus_strain_rt (nullable) is None
        # and model_fields_set contains the field
        if self.inj1_virus_strain_rt is None and "inj1_virus_strain_rt" in self.model_fields_set:
            _dict['Inj1VirusStrain_rt'] = None

        # set to None if inj1volperdepth (nullable) is None
        # and model_fields_set contains the field
        if self.inj1volperdepth is None and "inj1volperdepth" in self.model_fields_set:
            _dict['inj1volperdepth'] = None

        # set to None if inj2_alternating_time (nullable) is None
        # and model_fields_set contains the field
        if self.inj2_alternating_time is None and "inj2_alternating_time" in self.model_fields_set:
            _dict['Inj2AlternatingTime'] = None

        # set to None if inj2_angle_v2 (nullable) is None
        # and model_fields_set contains the field
        if self.inj2_angle_v2 is None and "inj2_angle_v2" in self.model_fields_set:
            _dict['Inj2Angle_v2'] = None

        # set to None if inj2_current (nullable) is None
        # and model_fields_set contains the field
        if self.inj2_current is None and "inj2_current" in self.model_fields_set:
            _dict['Inj2Current'] = None

        # set to None if inj2_ionto_time (nullable) is None
        # and model_fields_set contains the field
        if self.inj2_ionto_time is None and "inj2_ionto_time" in self.model_fields_set:
            _dict['Inj2IontoTime'] = None

        # set to None if inj2_storage_location (nullable) is None
        # and model_fields_set contains the field
        if self.inj2_storage_location is None and "inj2_storage_location" in self.model_fields_set:
            _dict['Inj2StorageLocation'] = None

        # set to None if inj2_virus_strain_rt (nullable) is None
        # and model_fields_set contains the field
        if self.inj2_virus_strain_rt is None and "inj2_virus_strain_rt" in self.model_fields_set:
            _dict['Inj2VirusStrain_rt'] = None

        # set to None if inj2volperdepth (nullable) is None
        # and model_fields_set contains the field
        if self.inj2volperdepth is None and "inj2volperdepth" in self.model_fields_set:
            _dict['inj2volperdepth'] = None

        # set to None if inj3_alternating_time (nullable) is None
        # and model_fields_set contains the field
        if self.inj3_alternating_time is None and "inj3_alternating_time" in self.model_fields_set:
            _dict['Inj3AlternatingTime'] = None

        # set to None if inj3_current (nullable) is None
        # and model_fields_set contains the field
        if self.inj3_current is None and "inj3_current" in self.model_fields_set:
            _dict['Inj3Current'] = None

        # set to None if inj3_ionto_time (nullable) is None
        # and model_fields_set contains the field
        if self.inj3_ionto_time is None and "inj3_ionto_time" in self.model_fields_set:
            _dict['Inj3IontoTime'] = None

        # set to None if inj3_storage_location (nullable) is None
        # and model_fields_set contains the field
        if self.inj3_storage_location is None and "inj3_storage_location" in self.model_fields_set:
            _dict['Inj3StorageLocation'] = None

        # set to None if inj3volperdepth (nullable) is None
        # and model_fields_set contains the field
        if self.inj3volperdepth is None and "inj3volperdepth" in self.model_fields_set:
            _dict['Inj3volperdepth'] = None

        # set to None if inj4_alternating_time (nullable) is None
        # and model_fields_set contains the field
        if self.inj4_alternating_time is None and "inj4_alternating_time" in self.model_fields_set:
            _dict['Inj4AlternatingTime'] = None

        # set to None if inj4_current (nullable) is None
        # and model_fields_set contains the field
        if self.inj4_current is None and "inj4_current" in self.model_fields_set:
            _dict['Inj4Current'] = None

        # set to None if inj4_ionto_time (nullable) is None
        # and model_fields_set contains the field
        if self.inj4_ionto_time is None and "inj4_ionto_time" in self.model_fields_set:
            _dict['Inj4IontoTime'] = None

        # set to None if inj4_storage_location (nullable) is None
        # and model_fields_set contains the field
        if self.inj4_storage_location is None and "inj4_storage_location" in self.model_fields_set:
            _dict['Inj4StorageLocation'] = None

        # set to None if inj4_virus_strain_rt (nullable) is None
        # and model_fields_set contains the field
        if self.inj4_virus_strain_rt is None and "inj4_virus_strain_rt" in self.model_fields_set:
            _dict['Inj4VirusStrain_rt'] = None

        # set to None if inj4volperdepth (nullable) is None
        # and model_fields_set contains the field
        if self.inj4volperdepth is None and "inj4volperdepth" in self.model_fields_set:
            _dict['Inj4volperdepth'] = None

        # set to None if inj5_alternating_time (nullable) is None
        # and model_fields_set contains the field
        if self.inj5_alternating_time is None and "inj5_alternating_time" in self.model_fields_set:
            _dict['Inj5AlternatingTime'] = None

        # set to None if inj5_current (nullable) is None
        # and model_fields_set contains the field
        if self.inj5_current is None and "inj5_current" in self.model_fields_set:
            _dict['Inj5Current'] = None

        # set to None if inj5_ionto_time (nullable) is None
        # and model_fields_set contains the field
        if self.inj5_ionto_time is None and "inj5_ionto_time" in self.model_fields_set:
            _dict['Inj5IontoTime'] = None

        # set to None if inj5_storage_location (nullable) is None
        # and model_fields_set contains the field
        if self.inj5_storage_location is None and "inj5_storage_location" in self.model_fields_set:
            _dict['Inj5StorageLocation'] = None

        # set to None if inj5_virus_strain_rt (nullable) is None
        # and model_fields_set contains the field
        if self.inj5_virus_strain_rt is None and "inj5_virus_strain_rt" in self.model_fields_set:
            _dict['Inj5VirusStrain_rt'] = None

        # set to None if inj5volperdepth (nullable) is None
        # and model_fields_set contains the field
        if self.inj5volperdepth is None and "inj5volperdepth" in self.model_fields_set:
            _dict['inj5volperdepth'] = None

        # set to None if inj6_alternating_time (nullable) is None
        # and model_fields_set contains the field
        if self.inj6_alternating_time is None and "inj6_alternating_time" in self.model_fields_set:
            _dict['Inj6AlternatingTime'] = None

        # set to None if inj6_current (nullable) is None
        # and model_fields_set contains the field
        if self.inj6_current is None and "inj6_current" in self.model_fields_set:
            _dict['Inj6Current'] = None

        # set to None if inj6_ionto_time (nullable) is None
        # and model_fields_set contains the field
        if self.inj6_ionto_time is None and "inj6_ionto_time" in self.model_fields_set:
            _dict['Inj6IontoTime'] = None

        # set to None if inj6_storage_location (nullable) is None
        # and model_fields_set contains the field
        if self.inj6_storage_location is None and "inj6_storage_location" in self.model_fields_set:
            _dict['Inj6StorageLocation'] = None

        # set to None if inj6_virus_strain_rt (nullable) is None
        # and model_fields_set contains the field
        if self.inj6_virus_strain_rt is None and "inj6_virus_strain_rt" in self.model_fields_set:
            _dict['Inj6VirusStrain_rt'] = None

        # set to None if inj6volperdepth (nullable) is None
        # and model_fields_set contains the field
        if self.inj6volperdepth is None and "inj6volperdepth" in self.model_fields_set:
            _dict['inj6volperdepth'] = None

        # set to None if inj_virus_strain_rt (nullable) is None
        # and model_fields_set contains the field
        if self.inj_virus_strain_rt is None and "inj_virus_strain_rt" in self.model_fields_set:
            _dict['InjVirusStrain_rt'] = None

        # set to None if is_record (nullable) is None
        # and model_fields_set contains the field
        if self.is_record is None and "is_record" in self.model_fields_set:
            _dict['_IsRecord'] = None

        # set to None if iso_x0020_on (nullable) is None
        # and model_fields_set contains the field
        if self.iso_x0020_on is None and "iso_x0020_on" in self.model_fields_set:
            _dict['Iso_x0020_On'] = None

        # set to None if item_child_count (nullable) is None
        # and model_fields_set contains the field
        if self.item_child_count is None and "item_child_count" in self.model_fields_set:
            _dict['ItemChildCount'] = None

        # set to None if lab_tracks_x0020_group (nullable) is None
        # and model_fields_set contains the field
        if self.lab_tracks_x0020_group is None and "lab_tracks_x0020_group" in self.model_fields_set:
            _dict['LabTracks_x0020_Group'] = None

        # set to None if lab_tracks_x0020_requestor (nullable) is None
        # and model_fields_set contains the field
        if self.lab_tracks_x0020_requestor is None and "lab_tracks_x0020_requestor" in self.model_fields_set:
            _dict['LabTracks_x0020_Requestor'] = None

        # set to None if lab_tracks_x0020_id1 (nullable) is None
        # and model_fields_set contains the field
        if self.lab_tracks_x0020_id1 is None and "lab_tracks_x0020_id1" in self.model_fields_set:
            _dict['LabTracks_x0020_ID1'] = None

        # set to None if link_title (nullable) is None
        # and model_fields_set contains the field
        if self.link_title is None and "link_title" in self.model_fields_set:
            _dict['LinkTitle'] = None

        # set to None if link_title_no_menu (nullable) is None
        # and model_fields_set contains the field
        if self.link_title_no_menu is None and "link_title_no_menu" in self.model_fields_set:
            _dict['LinkTitleNoMenu'] = None

        # set to None if long_requestor_comments (nullable) is None
        # and model_fields_set contains the field
        if self.long_requestor_comments is None and "long_requestor_comments" in self.model_fields_set:
            _dict['LongRequestorComments'] = None

        # set to None if ml2nd_inj (nullable) is None
        # and model_fields_set contains the field
        if self.ml2nd_inj is None and "ml2nd_inj" in self.model_fields_set:
            _dict['ML2ndInj'] = None

        # set to None if modified (nullable) is None
        # and model_fields_set contains the field
        if self.modified is None and "modified" in self.model_fields_set:
            _dict['Modified'] = None

        # set to None if non_x002d_nsb_x0020_surgeon (nullable) is None
        # and model_fields_set contains the field
        if self.non_x002d_nsb_x0020_surgeon is None and "non_x002d_nsb_x0020_surgeon" in self.model_fields_set:
            _dict['Non_x002d_NSB_x0020_Surgeon'] = None

        # set to None if pedigree_name (nullable) is None
        # and model_fields_set contains the field
        if self.pedigree_name is None and "pedigree_name" in self.model_fields_set:
            _dict['PedigreeName'] = None

        # set to None if pi (nullable) is None
        # and model_fields_set contains the field
        if self.pi is None and "pi" in self.model_fields_set:
            _dict['PI'] = None

        # set to None if round1_inj_isolevel (nullable) is None
        # and model_fields_set contains the field
        if self.round1_inj_isolevel is None and "round1_inj_isolevel" in self.model_fields_set:
            _dict['Round1InjIsolevel'] = None

        # set to None if test1 (nullable) is None
        # and model_fields_set contains the field
        if self.test1 is None and "test1" in self.model_fields_set:
            _dict['Test1'] = None

        # set to None if test_x0020_1st_x0020_round_x0020 (nullable) is None
        # and model_fields_set contains the field
        if self.test_x0020_1st_x0020_round_x0020 is None and "test_x0020_1st_x0020_round_x0020" in self.model_fields_set:
            _dict['TEST_x0020_1st_x0020_Round_x0020'] = None

        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict['Title'] = None

        # set to None if ui_version_string (nullable) is None
        # and model_fields_set contains the field
        if self.ui_version_string is None and "ui_version_string" in self.model_fields_set:
            _dict['_UIVersionString'] = None

        # set to None if virus_x0020_a_x002f_p (nullable) is None
        # and model_fields_set contains the field
        if self.virus_x0020_a_x002f_p is None and "virus_x0020_a_x002f_p" in self.model_fields_set:
            _dict['Virus_x0020_A_x002f_P'] = None

        # set to None if virus_x0020_d_x002f_v (nullable) is None
        # and model_fields_set contains the field
        if self.virus_x0020_d_x002f_v is None and "virus_x0020_d_x002f_v" in self.model_fields_set:
            _dict['Virus_x0020_D_x002f_V'] = None

        # set to None if virus_x0020_m_x002f_l (nullable) is None
        # and model_fields_set contains the field
        if self.virus_x0020_m_x002f_l is None and "virus_x0020_m_x002f_l" in self.model_fields_set:
            _dict['Virus_x0020_M_x002f_L'] = None

        # set to None if weight_x0020_after_x0020_surgery (nullable) is None
        # and model_fields_set contains the field
        if self.weight_x0020_after_x0020_surgery is None and "weight_x0020_after_x0020_surgery" in self.model_fields_set:
            _dict['Weight_x0020_after_x0020_Surgery'] = None

        # set to None if weight_x0020_before_x0020_surger (nullable) is None
        # and model_fields_set contains the field
        if self.weight_x0020_before_x0020_surger is None and "weight_x0020_before_x0020_surger" in self.model_fields_set:
            _dict['Weight_x0020_before_x0020_Surger'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of NSB2023List from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "Age_x0020_at_x0020_Injection": obj.get("Age_x0020_at_x0020_Injection"),
            "AIND_x0020_Project_x0020_Name": obj.get("AIND_x0020_Project_x0020_Name"),
            "AP2ndInj": obj.get("AP2ndInj"),
            "AppAuthor": obj.get("AppAuthor"),
            "AppEditor": obj.get("AppEditor"),
            "Attachments": obj.get("Attachments"),
            "Author": obj.get("Author"),
            "AuthorId": obj.get("AuthorId"),
            "AuthorLookupId": obj.get("AuthorLookupId"),
            "EditorId": obj.get("EditorId"),
            "EditorLookupId": obj.get("EditorLookupId"),
            "Test1LookupId": obj.get("Test1LookupId"),
            "TEST_x0020_1st_x0020_Round_x0020LookupId": obj.get("TEST_x0020_1st_x0020_Round_x0020LookupId"),
            "Behavior": obj.get("Behavior"),
            "Behavior_x0020_Autotrain_x0020_C": obj.get("Behavior_x0020_Autotrain_x0020_C"),
            "Behavior_x0020_Complete": obj.get("Behavior_x0020_Complete"),
            "Behavior_x0020_Curriculum_x0020_": obj.get("Behavior_x0020_Curriculum_x0020_"),
            "behavior_x0020_Destination": obj.get("behavior_x0020_Destination"),
            "Behavior_x0020_Fiber_x0020_Photo": obj.get("Behavior_x0020_Fiber_x0020_Photo"),
            "Behavior_x0020_First_x0020_Video": obj.get("Behavior_x0020_First_x0020_Video"),
            "Behavior_x0020_First_x0020_FIP_x": obj.get("Behavior_x0020_First_x0020_FIP_x"),
            "Behavior_x0020_Platform": obj.get("Behavior_x0020_Platform"),
            "Behavior_x0020_Type": obj.get("Behavior_x0020_Type"),
            "Behavior_x0020_FIP_x0020_Mode": obj.get("Behavior_x0020_FIP_x0020_Mode"),
            "Black_x0020_Cement": obj.get("Black_x0020_Cement"),
            "Breg2Lamb": obj.get("Breg2Lamb"),
            "Burr1_x0020_Injection_x0020_Devi": obj.get("Burr1_x0020_Injection_x0020_Devi"),
            "Burr1_x0020_Perform_x0020_During": obj.get("Burr1_x0020_Perform_x0020_During"),
            "Burr1_x0020_Virus_x0020_Biosafte": obj.get("Burr1_x0020_Virus_x0020_Biosafte"),
            "Burr2_x0020_Injection_x0020_Devi": obj.get("Burr2_x0020_Injection_x0020_Devi"),
            "Burr2_x0020_Perform_x0020_During": obj.get("Burr2_x0020_Perform_x0020_During"),
            "Burr2_x0020_Status": obj.get("Burr2_x0020_Status"),
            "Burr2_x0020_Virus_x0020_Biosafte": obj.get("Burr2_x0020_Virus_x0020_Biosafte"),
            "Burr3_x0020_Injection_x0020_Devi": obj.get("Burr3_x0020_Injection_x0020_Devi"),
            "Burr3_x0020_Perform_x0020_During": obj.get("Burr3_x0020_Perform_x0020_During"),
            "Burr3_x0020_Status": obj.get("Burr3_x0020_Status"),
            "Burr3_x0020_Virus_x0020_Biosafet": obj.get("Burr3_x0020_Virus_x0020_Biosafet"),
            "Burr3_x0020_A_x002f_P": obj.get("Burr3_x0020_A_x002f_P"),
            "Burr3_x0020_D_x002f_V": obj.get("Burr3_x0020_D_x002f_V"),
            "Burr3_x0020_M_x002f_L": obj.get("Burr3_x0020_M_x002f_L"),
            "Burr4_x0020_Injection_x0020_Devi": obj.get("Burr4_x0020_Injection_x0020_Devi"),
            "Burr4_x0020_Perform_x0020_During": obj.get("Burr4_x0020_Perform_x0020_During"),
            "Burr4_x0020_Status": obj.get("Burr4_x0020_Status"),
            "Burr4_x0020_Virus_x0020_Biosafte": obj.get("Burr4_x0020_Virus_x0020_Biosafte"),
            "Burr4_x0020_A_x002f_P": obj.get("Burr4_x0020_A_x002f_P"),
            "Burr4_x0020_D_x002f_V": obj.get("Burr4_x0020_D_x002f_V"),
            "Burr4_x0020_M_x002f_L": obj.get("Burr4_x0020_M_x002f_L"),
            "Burr5_x0020_Injection_x0020_Devi": obj.get("Burr5_x0020_Injection_x0020_Devi"),
            "Burr5_x0020_Perform_x0020_During": obj.get("Burr5_x0020_Perform_x0020_During"),
            "Burr5_x0020_Status": obj.get("Burr5_x0020_Status"),
            "Burr5_x0020_Virus_x0020_Biosafte": obj.get("Burr5_x0020_Virus_x0020_Biosafte"),
            "Burr6_x0020_Injection_x0020_Devi": obj.get("Burr6_x0020_Injection_x0020_Devi"),
            "Burr6_x0020_Perform_x0020_During": obj.get("Burr6_x0020_Perform_x0020_During"),
            "Burr6_x0020_Status": obj.get("Burr6_x0020_Status"),
            "Burr6_x0020_Virus_x0020_Biosafte": obj.get("Burr6_x0020_Virus_x0020_Biosafte"),
            "Burr_x0020_1_x0020_Fiber_x0020_t": obj.get("Burr_x0020_1_x0020_Fiber_x0020_t"),
            "Burr_x0020_1_x0020_Grid_x0020_Sp": obj.get("Burr_x0020_1_x0020_Grid_x0020_Sp"),
            "Burr_x0020_1_x0020_Injectable_x00": obj.get("Burr_x0020_1_x0020_Injectable_x00"),
            "Burr_x0020_1_x0020_Injectable_x01": obj.get("Burr_x0020_1_x0020_Injectable_x01"),
            "Burr_x0020_1_x0020_Injectable_x02": obj.get("Burr_x0020_1_x0020_Injectable_x02"),
            "Burr_x0020_1_x0020_Injectable_x03": obj.get("Burr_x0020_1_x0020_Injectable_x03"),
            "Burr_x0020_1_x0020_Injectable_x04": obj.get("Burr_x0020_1_x0020_Injectable_x04"),
            "Burr_x0020_1_x0020_Injectable_x05": obj.get("Burr_x0020_1_x0020_Injectable_x05"),
            "Burr_x0020_1_x0020_Injectable_x06": obj.get("Burr_x0020_1_x0020_Injectable_x06"),
            "Burr_x0020_1_x0020_Injectable_x0": obj.get("Burr_x0020_1_x0020_Injectable_x0"),
            "Burr_x0020_1_x0020_Intended_x002": obj.get("Burr_x0020_1_x0020_Intended_x002"),
            "Burr_x0020_1_x0020_Spinal_x0020_": obj.get("Burr_x0020_1_x0020_Spinal_x0020_"),
            "Burr_x0020_1_x0020_D_x002f_V_x00": obj.get("Burr_x0020_1_x0020_D_x002f_V_x00"),
            "Burr_x0020_1_x0020_DV_x0020_2": obj.get("Burr_x0020_1_x0020_DV_x0020_2"),
            "Burr_x0020_1_x0020_intended_x0020": obj.get("Burr_x0020_1_x0020_intended_x0020"),
            "Burr_x0020_1_x0020_intended_x0021": obj.get("Burr_x0020_1_x0020_intended_x0021"),
            "Burr_x0020_1_x0020_intended_x0022": obj.get("Burr_x0020_1_x0020_intended_x0022"),
            "Burr_x0020_1_x0020_intended_x0023": obj.get("Burr_x0020_1_x0020_intended_x0023"),
            "Burr_x0020_2_x0020_Fiber_x0020_T": obj.get("Burr_x0020_2_x0020_Fiber_x0020_T"),
            "Burr_x0020_2_x0020_Injectable_x00": obj.get("Burr_x0020_2_x0020_Injectable_x00"),
            "Burr_x0020_2_x0020_Injectable_x01": obj.get("Burr_x0020_2_x0020_Injectable_x01"),
            "Burr_x0020_2_x0020_Injectable_x02": obj.get("Burr_x0020_2_x0020_Injectable_x02"),
            "Burr_x0020_2_x0020_Injectable_x03": obj.get("Burr_x0020_2_x0020_Injectable_x03"),
            "Burr_x0020_2_x0020_Injectable_x04": obj.get("Burr_x0020_2_x0020_Injectable_x04"),
            "Burr_x0020_2_x0020_Injectable_x05": obj.get("Burr_x0020_2_x0020_Injectable_x05"),
            "Burr_x0020_2_x0020_Injectable_x06": obj.get("Burr_x0020_2_x0020_Injectable_x06"),
            "Burr_x0020_2_x0020_Injectable_x0": obj.get("Burr_x0020_2_x0020_Injectable_x0"),
            "Burr_x0020_2_x0020_Intended_x002": obj.get("Burr_x0020_2_x0020_Intended_x002"),
            "Burr_x0020_2_x0020_Spinal_x0020_": obj.get("Burr_x0020_2_x0020_Spinal_x0020_"),
            "Burr_x0020_2_x0020_D_x002f_V_x000": obj.get("Burr_x0020_2_x0020_D_x002f_V_x000"),
            "Burr_x0020_2_x0020_D_x002f_V_x00": obj.get("Burr_x0020_2_x0020_D_x002f_V_x00"),
            "Burr_x0020_2_x0020_intended_x0020": obj.get("Burr_x0020_2_x0020_intended_x0020"),
            "Burr_x0020_2_x0020_intended_x0021": obj.get("Burr_x0020_2_x0020_intended_x0021"),
            "Burr_x0020_2_x0020_intended_x0022": obj.get("Burr_x0020_2_x0020_intended_x0022"),
            "Burr_x0020_2_x0020_intended_x0023": obj.get("Burr_x0020_2_x0020_intended_x0023"),
            "Burr_x0020_3_x0020_Angle": obj.get("Burr_x0020_3_x0020_Angle"),
            "Burr_x0020_3_x0020_Fiber_x0020_T": obj.get("Burr_x0020_3_x0020_Fiber_x0020_T"),
            "Burr_x0020_3_x0020_Hemisphere": obj.get("Burr_x0020_3_x0020_Hemisphere"),
            "Burr_x0020_3_x0020_Injectable_x00": obj.get("Burr_x0020_3_x0020_Injectable_x00"),
            "Burr_x0020_3_x0020_Injectable_x01": obj.get("Burr_x0020_3_x0020_Injectable_x01"),
            "Burr_x0020_3_x0020_Injectable_x02": obj.get("Burr_x0020_3_x0020_Injectable_x02"),
            "Burr_x0020_3_x0020_Injectable_x03": obj.get("Burr_x0020_3_x0020_Injectable_x03"),
            "Burr_x0020_3_x0020_Injectable_x04": obj.get("Burr_x0020_3_x0020_Injectable_x04"),
            "Burr_x0020_3_x0020_Injectable_x05": obj.get("Burr_x0020_3_x0020_Injectable_x05"),
            "Burr_x0020_3_x0020_Injectable_x06": obj.get("Burr_x0020_3_x0020_Injectable_x06"),
            "Burr_x0020_3_x0020_Injectable_x0": obj.get("Burr_x0020_3_x0020_Injectable_x0"),
            "Burr_x0020_3_x0020_Intended_x002": obj.get("Burr_x0020_3_x0020_Intended_x002"),
            "Burr_x0020_3_x0020_D_x002f_V_x000": obj.get("Burr_x0020_3_x0020_D_x002f_V_x000"),
            "Burr_x0020_3_x0020_D_x002f_V_x00": obj.get("Burr_x0020_3_x0020_D_x002f_V_x00"),
            "Burr_x0020_3_x0020_intended_x0020": obj.get("Burr_x0020_3_x0020_intended_x0020"),
            "Burr_x0020_3_x0020_intended_x0021": obj.get("Burr_x0020_3_x0020_intended_x0021"),
            "Burr_x0020_3_x0020_intended_x0022": obj.get("Burr_x0020_3_x0020_intended_x0022"),
            "Burr_x0020_3_x0020_intended_x0023": obj.get("Burr_x0020_3_x0020_intended_x0023"),
            "Burr_x0020_4_x0020_Angle": obj.get("Burr_x0020_4_x0020_Angle"),
            "Burr_x0020_4_x0020_Fiber_x0020_T": obj.get("Burr_x0020_4_x0020_Fiber_x0020_T"),
            "Burr_x0020_4_x0020_Hemisphere": obj.get("Burr_x0020_4_x0020_Hemisphere"),
            "Burr_x0020_4_x0020_Injectable_x00": obj.get("Burr_x0020_4_x0020_Injectable_x00"),
            "Burr_x0020_4_x0020_Injectable_x01": obj.get("Burr_x0020_4_x0020_Injectable_x01"),
            "Burr_x0020_4_x0020_Injectable_x02": obj.get("Burr_x0020_4_x0020_Injectable_x02"),
            "Burr_x0020_4_x0020_Injectable_x03": obj.get("Burr_x0020_4_x0020_Injectable_x03"),
            "Burr_x0020_4_x0020_Injectable_x04": obj.get("Burr_x0020_4_x0020_Injectable_x04"),
            "Burr_x0020_4_x0020_Injectable_x05": obj.get("Burr_x0020_4_x0020_Injectable_x05"),
            "Burr_x0020_4_x0020_Injectable_x06": obj.get("Burr_x0020_4_x0020_Injectable_x06"),
            "Burr_x0020_4_x0020_Injectable_x0": obj.get("Burr_x0020_4_x0020_Injectable_x0"),
            "Burr_x0020_4_x0020_Intended_x002": obj.get("Burr_x0020_4_x0020_Intended_x002"),
            "Burr_x0020_4_x0020_D_x002f_V_x000": obj.get("Burr_x0020_4_x0020_D_x002f_V_x000"),
            "Burr_x0020_4_x0020_D_x002f_V_x00": obj.get("Burr_x0020_4_x0020_D_x002f_V_x00"),
            "Burr_x0020_4_x0020_intended_x0020": obj.get("Burr_x0020_4_x0020_intended_x0020"),
            "Burr_x0020_4_x0020_intended_x0021": obj.get("Burr_x0020_4_x0020_intended_x0021"),
            "Burr_x0020_4_x0020_intended_x0022": obj.get("Burr_x0020_4_x0020_intended_x0022"),
            "Burr_x0020_4_x0020_intended_x0023": obj.get("Burr_x0020_4_x0020_intended_x0023"),
            "Burr_x0020_5_x0020_Angle": obj.get("Burr_x0020_5_x0020_Angle"),
            "Burr_x0020_5_x0020_Fiber_x0020_t": obj.get("Burr_x0020_5_x0020_Fiber_x0020_t"),
            "Burr_x0020_5_x0020_Hemisphere": obj.get("Burr_x0020_5_x0020_Hemisphere"),
            "Burr_x0020_5_x0020_Injectable_x00": obj.get("Burr_x0020_5_x0020_Injectable_x00"),
            "Burr_x0020_5_x0020_Injectable_x01": obj.get("Burr_x0020_5_x0020_Injectable_x01"),
            "Burr_x0020_5_x0020_Injectable_x02": obj.get("Burr_x0020_5_x0020_Injectable_x02"),
            "Burr_x0020_5_x0020_Injectable_x03": obj.get("Burr_x0020_5_x0020_Injectable_x03"),
            "Burr_x0020_5_x0020_Injectable_x04": obj.get("Burr_x0020_5_x0020_Injectable_x04"),
            "Burr_x0020_5_x0020_Injectable_x05": obj.get("Burr_x0020_5_x0020_Injectable_x05"),
            "Burr_x0020_5_x0020_Injectable_x06": obj.get("Burr_x0020_5_x0020_Injectable_x06"),
            "Burr_x0020_5_x0020_Injectable_x0": obj.get("Burr_x0020_5_x0020_Injectable_x0"),
            "Burr_x0020_5_x0020_Intended_x002": obj.get("Burr_x0020_5_x0020_Intended_x002"),
            "Burr_x0020_5_x0020_A_x002f_P": obj.get("Burr_x0020_5_x0020_A_x002f_P"),
            "Burr_x0020_5_x0020_D_x002f_V_x000": obj.get("Burr_x0020_5_x0020_D_x002f_V_x000"),
            "Burr_x0020_5_x0020_D_x002f_V_x001": obj.get("Burr_x0020_5_x0020_D_x002f_V_x001"),
            "Burr_x0020_5_x0020_D_x002f_V_x00": obj.get("Burr_x0020_5_x0020_D_x002f_V_x00"),
            "Burr_x0020_5_x0020_intended_x0020": obj.get("Burr_x0020_5_x0020_intended_x0020"),
            "Burr_x0020_5_x0020_intended_x0021": obj.get("Burr_x0020_5_x0020_intended_x0021"),
            "Burr_x0020_5_x0020_intended_x0022": obj.get("Burr_x0020_5_x0020_intended_x0022"),
            "Burr_x0020_5_x0020_intended_x0023": obj.get("Burr_x0020_5_x0020_intended_x0023"),
            "Burr_x0020_5_x0020_M_x002f_L": obj.get("Burr_x0020_5_x0020_M_x002f_L"),
            "Burr_x0020_6_x0020_Angle": obj.get("Burr_x0020_6_x0020_Angle"),
            "Burr_x0020_6_x0020_Fiber_x0020_t": obj.get("Burr_x0020_6_x0020_Fiber_x0020_t"),
            "Burr_x0020_6_x0020_Hemisphere": obj.get("Burr_x0020_6_x0020_Hemisphere"),
            "Burr_x0020_6_x0020_Injectable_x00": obj.get("Burr_x0020_6_x0020_Injectable_x00"),
            "Burr_x0020_6_x0020_Injectable_x01": obj.get("Burr_x0020_6_x0020_Injectable_x01"),
            "Burr_x0020_6_x0020_Injectable_x02": obj.get("Burr_x0020_6_x0020_Injectable_x02"),
            "Burr_x0020_6_x0020_Injectable_x03": obj.get("Burr_x0020_6_x0020_Injectable_x03"),
            "Burr_x0020_6_x0020_Injectable_x04": obj.get("Burr_x0020_6_x0020_Injectable_x04"),
            "Burr_x0020_6_x0020_Injectable_x05": obj.get("Burr_x0020_6_x0020_Injectable_x05"),
            "Burr_x0020_6_x0020_Injectable_x06": obj.get("Burr_x0020_6_x0020_Injectable_x06"),
            "Burr_x0020_6_x0020_Injectable_x0": obj.get("Burr_x0020_6_x0020_Injectable_x0"),
            "Burr_x0020_6_x0020_Intended_x002": obj.get("Burr_x0020_6_x0020_Intended_x002"),
            "Burr_x0020_6_x0020_A_x002f_P": obj.get("Burr_x0020_6_x0020_A_x002f_P"),
            "Burr_x0020_6_x0020_D_x002f_V_x000": obj.get("Burr_x0020_6_x0020_D_x002f_V_x000"),
            "Burr_x0020_6_x0020_D_x002f_V_x001": obj.get("Burr_x0020_6_x0020_D_x002f_V_x001"),
            "Burr_x0020_6_x0020_D_x002f_V_x00": obj.get("Burr_x0020_6_x0020_D_x002f_V_x00"),
            "Burr_x0020_6_x0020_intended_x0020": obj.get("Burr_x0020_6_x0020_intended_x0020"),
            "Burr_x0020_6_x0020_intended_x0021": obj.get("Burr_x0020_6_x0020_intended_x0021"),
            "Burr_x0020_6_x0020_intended_x0022": obj.get("Burr_x0020_6_x0020_intended_x0022"),
            "Burr_x0020_6_x0020_intended_x0023": obj.get("Burr_x0020_6_x0020_intended_x0023"),
            "Burr_x0020_6_x0020_M_x002f_L": obj.get("Burr_x0020_6_x0020_M_x002f_L"),
            "Burr_x0020_Hole_x0020_1_x0020_st": obj.get("Burr_x0020_Hole_x0020_1_x0020_st"),
            "Burr_x0020_hole_x0020_1": obj.get("Burr_x0020_hole_x0020_1"),
            "Burr_x0020_hole_x0020_2": obj.get("Burr_x0020_hole_x0020_2"),
            "Burr_x0020_hole_x0020_3": obj.get("Burr_x0020_hole_x0020_3"),
            "Burr_x0020_hole_x0020_4": obj.get("Burr_x0020_hole_x0020_4"),
            "Burr_x0020_hole_x0020_5": obj.get("Burr_x0020_hole_x0020_5"),
            "Burr_x0020_hole_x0020_6": obj.get("Burr_x0020_hole_x0020_6"),
            "Care_x0020_Moduele": obj.get("Care_x0020_Moduele"),
            "_ColorTag": obj.get("_ColorTag"),
            "ComCoplanar": obj.get("ComCoplanar"),
            "ComSinusbleed": obj.get("ComSinusbleed"),
            "ComSwelling": obj.get("ComSwelling"),
            "ComplianceAssetId": obj.get("ComplianceAssetId"),
            "ContentType": obj.get("ContentType"),
            "Contusion": obj.get("Contusion"),
            "Craniotomy_x0020_Perform_x0020_D": obj.get("Craniotomy_x0020_Perform_x0020_D"),
            "CraniotomyType": obj.get("CraniotomyType"),
            "Created": obj.get("Created"),
            "Date1stInjection": obj.get("Date1stInjection"),
            "Date_x0020_of_x0020_Birth": obj.get("Date_x0020_of_x0020_Birth"),
            "Date_x0020_of_x0020_Surgery": obj.get("Date_x0020_of_x0020_Surgery"),
            "DateRangeStart": obj.get("DateRangeStart"),
            "DocIcon": obj.get("DocIcon"),
            "DV2ndInj": obj.get("DV2ndInj"),
            "Edit": obj.get("Edit"),
            "Editor": obj.get("Editor"),
            "Fiber_x0020_Implant1_x0020_Lengt": obj.get("Fiber_x0020_Implant1_x0020_Lengt"),
            "Fiber_x0020_Implant2_x0020_Lengt": obj.get("Fiber_x0020_Implant2_x0020_Lengt"),
            "Fiber_x0020_Implant3_x0020_Lengt": obj.get("Fiber_x0020_Implant3_x0020_Lengt"),
            "Fiber_x0020_Implant3_x0020_D_x00": obj.get("Fiber_x0020_Implant3_x0020_D_x00"),
            "Fiber_x0020_Implant4_x0020_Lengt": obj.get("Fiber_x0020_Implant4_x0020_Lengt"),
            "Fiber_x0020_Implant4_x0020_D_x00": obj.get("Fiber_x0020_Implant4_x0020_D_x00"),
            "Fiber_x0020_Implant5_x0020_Lengt": obj.get("Fiber_x0020_Implant5_x0020_Lengt"),
            "Fiber_x0020_Implant5_x0020_D_x00": obj.get("Fiber_x0020_Implant5_x0020_D_x00"),
            "Fiber_x0020_Implant6_x0020_Lengt": obj.get("Fiber_x0020_Implant6_x0020_Lengt"),
            "Fiber_x0020_Implant6_x0020_D_x00": obj.get("Fiber_x0020_Implant6_x0020_D_x00"),
            "FiberImplant1DV": obj.get("FiberImplant1DV"),
            "FiberImplant2DV": obj.get("FiberImplant2DV"),
            "FirstInjRecovery": obj.get("FirstInjRecovery"),
            "FirstInjectionIsoDuration": obj.get("FirstInjectionIsoDuration"),
            "FirstInjectionWeightAfter": obj.get("FirstInjectionWeightAfter"),
            "FirstInjectionWeightBefor": obj.get("FirstInjectionWeightBefor"),
            "FolderChildCount": obj.get("FolderChildCount"),
            "Headpost": obj.get("Headpost"),
            "Headpost_x0020_Perform_x0020_Dur": obj.get("Headpost_x0020_Perform_x0020_Dur"),
            "HeadpostType": obj.get("HeadpostType"),
            "Hemisphere2ndInj": obj.get("Hemisphere2ndInj"),
            "HPIsoLevel": obj.get("HPIsoLevel"),
            "HPRecovery": obj.get("HPRecovery"),
            "HPSurgeonComments": obj.get("HPSurgeonComments"),
            "HpWorkStation": obj.get("HpWorkStation"),
            "IACUC_x0020_Protocol_x0020__x002": obj.get("IACUC_x0020_Protocol_x0020__x002"),
            "ID": obj.get("ID"),
            "ImplantIDCoverslipType": obj.get("ImplantIDCoverslipType"),
            "Inj1AlternatingTime": obj.get("Inj1AlternatingTime"),
            "Inj1Angle_v2": obj.get("Inj1Angle_v2"),
            "Inj1Current": obj.get("Inj1Current"),
            "Inj1IontoTime": obj.get("Inj1IontoTime"),
            "Inj1StorageLocation": obj.get("Inj1StorageLocation"),
            "Inj1Type": obj.get("Inj1Type"),
            "Inj1VirusStrain_rt": obj.get("Inj1VirusStrain_rt"),
            "inj1volperdepth": obj.get("inj1volperdepth"),
            "Inj2AlternatingTime": obj.get("Inj2AlternatingTime"),
            "Inj2Angle_v2": obj.get("Inj2Angle_v2"),
            "Inj2Current": obj.get("Inj2Current"),
            "Inj2IontoTime": obj.get("Inj2IontoTime"),
            "Inj2StorageLocation": obj.get("Inj2StorageLocation"),
            "Inj2Type": obj.get("Inj2Type"),
            "Inj2VirusStrain_rt": obj.get("Inj2VirusStrain_rt"),
            "inj2volperdepth": obj.get("inj2volperdepth"),
            "Inj3AlternatingTime": obj.get("Inj3AlternatingTime"),
            "Inj3Current": obj.get("Inj3Current"),
            "Inj3IontoTime": obj.get("Inj3IontoTime"),
            "Inj3StorageLocation": obj.get("Inj3StorageLocation"),
            "Inj3Type": obj.get("Inj3Type"),
            "Inj3retSetting": obj.get("Inj3retSetting"),
            "Inj3volperdepth": obj.get("Inj3volperdepth"),
            "Inj4AlternatingTime": obj.get("Inj4AlternatingTime"),
            "Inj4Current": obj.get("Inj4Current"),
            "Inj4IontoTime": obj.get("Inj4IontoTime"),
            "Inj4StorageLocation": obj.get("Inj4StorageLocation"),
            "Inj4Type": obj.get("Inj4Type"),
            "Inj4VirusStrain_rt": obj.get("Inj4VirusStrain_rt"),
            "Inj4retSetting": obj.get("Inj4retSetting"),
            "Inj4volperdepth": obj.get("Inj4volperdepth"),
            "Inj5AlternatingTime": obj.get("Inj5AlternatingTime"),
            "Inj5Current": obj.get("Inj5Current"),
            "Inj5IontoTime": obj.get("Inj5IontoTime"),
            "Inj5StorageLocation": obj.get("Inj5StorageLocation"),
            "Inj5Type": obj.get("Inj5Type"),
            "Inj5VirusStrain_rt": obj.get("Inj5VirusStrain_rt"),
            "Inj5retSetting": obj.get("Inj5retSetting"),
            "inj5volperdepth": obj.get("inj5volperdepth"),
            "Inj6AlternatingTime": obj.get("Inj6AlternatingTime"),
            "Inj6Current": obj.get("Inj6Current"),
            "Inj6IontoTime": obj.get("Inj6IontoTime"),
            "Inj6StorageLocation": obj.get("Inj6StorageLocation"),
            "Inj6Type": obj.get("Inj6Type"),
            "Inj6VirusStrain_rt": obj.get("Inj6VirusStrain_rt"),
            "Inj6retSetting": obj.get("Inj6retSetting"),
            "inj6volperdepth": obj.get("inj6volperdepth"),
            "InjVirusStrain_rt": obj.get("InjVirusStrain_rt"),
            "IontoNumberInj1": obj.get("IontoNumberInj1"),
            "IontoNumberInj2": obj.get("IontoNumberInj2"),
            "_IsRecord": obj.get("_IsRecord"),
            "Iso_x0020_On": obj.get("Iso_x0020_On"),
            "ItemChildCount": obj.get("ItemChildCount"),
            "LabTracks_x0020_Group": obj.get("LabTracks_x0020_Group"),
            "LabTracks_x0020_Requestor": obj.get("LabTracks_x0020_Requestor"),
            "LabTracks_x0020_ID1": obj.get("LabTracks_x0020_ID1"),
            "LIMs_x0020_Required": obj.get("LIMs_x0020_Required"),
            "LightCycle": obj.get("LightCycle"),
            "LIMSProject": obj.get("LIMSProject"),
            "LIMSTaskflow": obj.get("LIMSTaskflow"),
            "LinkTitle": obj.get("LinkTitle"),
            "LinkTitleNoMenu": obj.get("LinkTitleNoMenu"),
            "LongRequestorComments": obj.get("LongRequestorComments"),
            "ML2ndInj": obj.get("ML2ndInj"),
            "Modified": obj.get("Modified"),
            "NanojectNumberInj10": obj.get("NanojectNumberInj10"),
            "NanojectNumberInj2": obj.get("NanojectNumberInj2"),
            "Non_x002d_NSB_x0020_Surgeon": obj.get("Non_x002d_NSB_x0020_Surgeon"),
            "_x0023__x0020_of_x0020_Burr_x002": obj.get("_x0023__x0020_of_x0020_Burr_x002"),
            "PedigreeName": obj.get("PedigreeName"),
            "PI": obj.get("PI"),
            "Procedure": obj.get("Procedure"),
            "Procedure_x0020_Family": obj.get("Procedure_x0020_Family"),
            "Procedure_x0020_Slots": obj.get("Procedure_x0020_Slots"),
            "Procedure_x0020_T2": obj.get("Procedure_x0020_T2"),
            "ProjectID": obj.get("ProjectID"),
            "Protocol": obj.get("Protocol"),
            "retSetting0": obj.get("retSetting0"),
            "retSetting1": obj.get("retSetting1"),
            "Round1InjIsolevel": obj.get("Round1InjIsolevel"),
            "Sex": obj.get("Sex"),
            "SurgeryStatus": obj.get("SurgeryStatus"),
            "Test1": obj.get("Test1"),
            "TEST_x0020_1st_x0020_Round_x0020": obj.get("TEST_x0020_1st_x0020_Round_x0020"),
            "Thermistor": obj.get("Thermistor"),
            "Title": obj.get("Title"),
            "_UIVersionString": obj.get("_UIVersionString"),
            "Virus_x0020_Hemisphere": obj.get("Virus_x0020_Hemisphere"),
            "Virus_x0020_A_x002f_P": obj.get("Virus_x0020_A_x002f_P"),
            "Virus_x0020_D_x002f_V": obj.get("Virus_x0020_D_x002f_V"),
            "Virus_x0020_M_x002f_L": obj.get("Virus_x0020_M_x002f_L"),
            "Weight_x0020_after_x0020_Surgery": obj.get("Weight_x0020_after_x0020_Surgery"),
            "Weight_x0020_before_x0020_Surger": obj.get("Weight_x0020_before_x0020_Surger"),
            "WorkStation1stInjection": obj.get("WorkStation1stInjection")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj


